#!/usr/bin/python
#imports = ["os","sys"]
#for eachimport in imports:
#    import eachimport
import os
import sys
import subprocess
#import Pyro4
import pdb
import sequence

from modeller import *
from modeller.automodel import *    # Load the automodel class

class mold:
    def __init__(self,file_format_pir):
        self.file_format_pir = file_format_pir

    def make_build_profilepy(self):
        script = """\
from modeller import *

log.verbose()
env = environ()

#-- Prepare the input files

#-- Read in the sequence database
sdb = sequence_db(env)
sdb.read(seq_database_file='""" + self.__installfolder__() + """/pdb/pdb_95.pir', seq_database_format='PIR', chains_list='ALL', minmax_db_seq_len=(30, 4000), clean_sequences=True)

#-- Write the sequence database in binary form
sdb.write(seq_database_file='""" + self.__installfolder__() + """/pdb/pdb_95.bin', seq_database_format='BINARY', chains_list='ALL')

#-- Now, read in the binary database
sdb.read(seq_database_file='""" + self.__installfolder__() + """/pdb/pdb_95.bin', seq_database_format='BINARY', chains_list='ALL')

#-- Read in the target sequence/alignment
aln = alignment(env)
aln.append(file='""" + self.file_format_pir + """', alignment_format='PIR', align_codes='ALL')

#-- Convert the input sequence/alignment into
#   profile format
prf = aln.to_profile()

#-- Scan sequence database to pick up homologous sequences
prf.build(sdb, matrix_offset=-450, rr_file='${LIB}/blosum62.sim.mat', gap_penalties_1d=(-500, -50), n_prof_iterations=1, check_profile=False, max_aln_evalue=0.01)

#-- Write out the profile in text format
prf.write(file='""" + os.path.dirname(self.file_format_pir) + '/build_profile.prf'"""', profile_format='TEXT')

#-- Convert the profile back to alignment format
aln = prf.to_alignment()

#-- Write out the alignment fileo
aln.write(file='""" + os.path.dirname(self.file_format_pir) + '/build_profilePIR.ali' + """', alignment_format='PIR')
aln.write(file='""" + os.path.dirname(self.file_format_pir) + '/build_profilePAP.ali' + """', alignment_format='PAP')
"""
        arq = file(os.path.dirname(self.file_format_pir) + '/build_profile.py', 'w')
        arq.write(script)
        arq.close()

    def __installfolder__(self):
        '''Returns where the AutoModel was instaled'''
        return os.path.dirname(os.path.realpath(sys.argv[0]))
#        return "/home/joaoluiz/IC/AutoModelIIH"

    def __folder_of_model__(self):
        return(os.path.dirname(self.file_format_pir))

    def find_templates(self):
        processo = modeller_caller()
        processo.run(self.__folder_of_model__() + '/build_profile.py')

class Align:
    def __init__(self,pdb_folder,modeldir,pdb_file,seq_ali):
        self.seq_ali = modeldir + seq_ali
        self.pdb_folder = pdb_folder
        self.modeldir = modeldir
        self.pdb_file = pdb.pdb(modeldir + pdb_file)
        self.strname = self.pdb_file.NomedaEstrutura()
    def make_readseq_py(self):
        script = """\
    # Step 1: Readin the structure file
    #
    # Reading the structure and passing the sequence to a seg
    # file.
from modeller import *
env = environ()
env.io.hetatm = env.io.water = True
env.io.atom_files_directory = ['"""+ self.pdb_folder + """']
code = '""" + self.strname + """'   #   estrutura a ser lida#
mdl = model(env, file=code)
aln = alignment(env)
aln.append_model(mdl, align_codes=code)
aln.write(file='""" + self.modeldir + """/str.seq')
    """
        arq = file(self.modeldir + '/readseq.py', 'w')
        arq.write(script)
        arq.close()

    def make_readseq_py2(self):
      script = """\
    # Step 1: Readin the structure file
    #
    # Reading the structure and passing the sequence to a seg
    # file.

env = environ()
env.io.hetatm = env.io.water = True
env.io.atom_files_directory = ['"""+ self.pdb_folder + """']
code = '""" + self.strname + """'   #   estrutura a ser lida#
mdl = model(env, file=code)
aln = alignment(env)
aln.append_model(mdl, align_codes=code)
aln.write(file='""" + self.modeldir + """str.seq')
aln.write(file='""" + self.modeldir + """str.str')
    """
      arq = file(self.modeldir + 'readseq.py', 'w')
      arq.write(script)
      arq.close()

    def make_align2d_py(self):
          script = """\
from modeller import *

env = environ()
env.io.hetatm = env.io.water = True
env.io.atom_files_directory = ['""" + self.modeldir + """']
aln = alignment(env)
mdl = model(env, file='""" + self.strname + """', model_segment=('FIRST:""" + self.pdb_file.chains()[0]+ """','LAST:""" + self.pdb_file.chains()[-1] + """'))
aln.append_model(mdl, align_codes='""" + self.strname + """', atom_files='""" + self.strname  + """.pdb')
aln.append(file='""" + self.seq_ali + """', align_codes='seq.ali')
aln.align2d()
aln.write(file='""" + self.modeldir + """ali.ali', alignment_format='PIR')
aln.write(file='""" + self.modeldir + """ali.pap', alignment_format='PAP')
        """
          arq = file(self.modeldir + 'align2d.py', 'w')
          arq.write(script)
          arq.close()
    def __folder_of_model__(self):
        return self.modeldir

    def read_sequence(self):
        processo = modeller_caller()
        processo.run(self.__folder_of_model__() + '/readseq.py')

    def align_sequence(self):
        processo = modeller_caller()
        processo.run(self.__folder_of_model__() + '/align2d.py')

class Modeler:
    def __init__(self,pdb_folder,modeldir,pdb_file,ali_ali):
        self.ali_ali = modeldir + ali_ali
        self.pdb_folder = pdb_folder
        self.modeldir = modeldir
        self.seq = sequence.Sequence(self.ali_ali)
        print self.seq.structures_names()
        self.structures = str(self.seq.structures_names()[0:-1])[1:-1]

    def make_get_model_py(self):
        script = """\
from modeller import *
from modeller.automodel import *    # Load the automodel class
import os
os.chdir('""" + self.__folder_of_model__() + """')

log.verbose()

env = environ(rand_seed=-12312)  # To get different models from another script
# directories for input atom files
env.io.hetatm = env.io.water = True


env.io.atom_files_directory = ['""" + self.modeldir + """']
a = automodel(env,
              alnfile='""" + self.ali_ali + """',      # alignment filename (ali.ali)
              knowns=(""" + self.structures + """),             # codes of the templates (variavel da est)
              sequence='seq.ali',           # code of the target (seq.ali)
              assess_methods=assess.GA341)  # request GA341 assessment
a.starting_model= 1                 # index of the first model
a.ending_model  = 5                 # index of the last model
                                    # (determines how many models to calculate)
a.deviation = 4.0                   # has to >0 if more than 1 model

a.make()                            # do homology modelling"""
        arq = file(self.modeldir + 'get_model.py', 'w')
        arq.write(script)
        arq.close()

    def __folder_of_model__(self):
        return self.modeldir

    def model_sequence(self):
        processo = modeller_caller()
        processo.run(self.__folder_of_model__() + 'get_model.py')

    def get_results(self):
        folder = self.modeldir
        mof = 0
        filemof = ""
        for files in os.listdir(folder):
            if (files.startswith('seq.ali.B')):
                    arqr = file(folder + '/' + files, 'r')
                    arqr.readline()
                    linha = arqr.readline()
                    if (mof == 0) or (linha.partition(':      ')[2] < mof):
                            mof = linha.partition(':      ')[2]
                            filemof = folder + '/' + files
                            arqr.close()
        # if not (os.path.exists(folder + '/../results')):
        #         os.mkdir(folder + '/../results')
        # os.popen('cp '+ filemof +  ' ' + folder + '/../results/')
        return filemof

# class Evaluate:
#     def __init__(self,pdb_file,model_file,ali_ali_file,workdir):
#         self.pdb_file = workdir + os.path.basename(pdb_file)
#         self.model_file = workdir + os.path.basename(model_file)
#         self.ali_ali_file = workdir + os.path.basename(ali_ali_file)
#         self.workdir = workdir
#         self.evaluatedir = self.workdir
#         self.path = self.evaluatedir
#         self.dope_profile = None

#     def prepare_evaluate(self):
#         pastaevaluate = self.workdir + 'evaluate/'
#         if(os.path.exists(pastaevaluate) == False):
#             os.mkdir(pastaevaluate)
#         os.popen("cp "+ self.pdb_file + " " + pastaevaluate)
#         os.popen("cp "+ self.model_file + " " + pastaevaluate)
#         os.popen("cp "+ self.ali_ali_file + " " + pastaevaluate)
#         return(pastaevaluate)

#     def make_evaluate_model(self,arquivopdb):
#             script = """\
# from modeller import *
# from modeller.scripts import complete_pdb

# log.verbose()    # request verbose output
# env = environ()
# env.libs.topology.read(file='$(LIB)/top_heav.lib') # read topology
# env.libs.parameters.read(file='$(LIB)/par.lib') # read parameters

# # read model file
# mdl = complete_pdb(env, '"""+ self.evaluatedir + os.path.basename(arquivopdb) + """')

# # Assess with DOPE:
# s = selection(mdl)   # all atom selection
# s.assess_dope(output='ENERGY_PROFILE NO_REPORT', file='"""+ self.evaluatedir  + os.path.basename(arquivopdb.split(".")[0]) + """.profile',
#               normalize_profile=True, smoothing_window=15)"""
#             arq = file(self.evaluatedir + 'evaluate_model.py', 'w')
#             arq.write(script)
#             arq.close()


#     def get_dope_profile(self):
#         return self.dope_profile

#     def __folder_of_evaluate__(self):
#         return self.evaluatedir

#     def get_evaluate(self):
#         processo = modeller_caller()
#         processo.run(self.__folder_of_evaluate__() + 'evaluate_model.py')

#     def plot_profiles(self):
#       self.create_script_in_folder(self.pdb_file, self.model_file)
#       processo = modeller_caller()
#       processo.run(self.__folder_of_evaluate__() + 'plot_profile.py')

#     def create_script_in_folder(self, template,model):
#         template = os.path.basename(template)[0:-4]
#         model = os.path.basename(model)[0:-4]
#         # myloop = os.path.basename(myloop)[0:-4]
#         # self.path = os.path.dirname(model)
#         pdbtemplate = pdb.pdb(self.pdb_file)
#         script = """import pylab
# import modeller
# import os

# os.chdir('""" + self.path + """')
# def get_profile(profile_file, seq):
#     '''Read `profile_file` into a Python array, and add gaps corresponding to
#        the alignment sequence `seq`.'''
#     # Read all non-comment and non-blank lines from the file:
#     f = file(profile_file)
#     vals = []
#     for line in f:
#         if not line.startswith('#') and len(line) > 10:
#             spl = line.split()
#             vals.append(float(spl[-1]))
#     # Insert gaps into the profile corresponding to those in seq:
#     for n, res in enumerate(seq.residues):
#         for gap in range(res.get_leading_gaps()):
#             vals.insert(n, None)
#     # Add a gap at position '0', so that we effectively count from 1:
#     vals.insert(0, None)
#     return vals

# e = modeller.environ()
# a = modeller.alignment(e, file='ali.ali')

# template = get_profile('""" + self.evaluatedir + os.path.basename(self.pdb_file).split(".")[0] + '.profile'"""', a['""" + str(pdbtemplate.NomedaEstrutura()) + """'])
# model = get_profile('""" + self.evaluatedir + os.path.basename(self.pdb_file).split(".")[0] + '.profile'"""', a['seq.ali'])
# # Plot the template and model profiles in the same plot for comparison:
# pylab.figure(1, figsize=(10,6))
# pylab.xlabel('Alignment position')
# pylab.ylabel('DOPE per-residue score')
# pylab.plot(model, color='red', linewidth=2, label='Model')
# pylab.plot(template, color='green', linewidth=2, label='Template')
# pylab.legend()
# pylab.savefig('dope_profile.png', dpi=65)
# """
#         script_path = self.path + os.sep + "plot_profile.py"
#         loop_script = file(script_path, "w")        
#         loop_script.write(script)
#         loop_script.close()
#         self.myscript = script_path
#         self.dope_profile = self.evaluatedir  + 'dope_profile.png'



    # def plot_profiles(self):
    #     import pylab
    #     import modeller
    #     pdbtemplate = pdb.pdb(self.pdb_file)
    #     def get_profile(profile_file, seq):
    #         # Read all non-comment and non-blank lines from the file:
    #         f = file(profile_file)
    #         vals = []

    #         for line in f:
    #             if not line.startswith('#') and len(line) > 10:
    #                 spl = line.split()
    #                 vals.append(float(spl[-1]))
    #         # Insert gaps into the profile corresponding to those in seq:
    #         for n, res in enumerate(seq.residues):
    #             for gap in range(res.get_leading_gaps()):
    #                 vals.insert(n, None)
    #         # Add a gap at position '0', so that we effectively count from 1:
    #         vals.insert(0, None)
    #         return vals
    #     e = modeller.environ()
    #     a = modeller.alignment(e, file=self.evaluatedir + 'ali.ali')
    #     print pdbtemplate.NomedaEstrutura()
    #     print self.evaluatedir + os.path.basename(self.pdb_file).split(".")[0] + '.profile'
    #     template = get_profile(self.evaluatedir + os.path.basename(self.pdb_file).split(".")[0] + '.profile', a[str(pdbtemplate.NomedaEstrutura())])
    #     model = get_profile(self.evaluatedir + os.path.basename(self.pdb_file).split(".")[0] + '.profile', a['seq.ali'])
    #     # Plot the template and model profiles in the same plot for comparison:
    #     pylab.figure(1, figsize=(10,6))
    #     pylab.xlabel('Alignment position')
    #     pylab.ylabel('DOPE per-residue score')
    #     pylab.plot(model, color='red', linewidth=2, label='Model')
    #     pylab.plot(template, color='green', linewidth=2, label='Template')
    #     pylab.legend()
    #     pylab.savefig(self.evaluatedir  + 'dope_profile.png', dpi=65)


    #     self.dope_profile = self.evaluatedir  + 'dope_profile.png'

class modeller_caller:
    def __init__(self):
        self.modeller_executable = "python"
        self.process = None
    def run(self,script):
        try:
            process = subprocess.Popen([self.modeller_executable,script])
        except:
            print "Modeller or Script not found!"
        return process.wait()

class Procheck_Evaluate:
    def __init__(self,workdir,template):
        self.workdir = workdir
        self.procheck_workdir = self.prepare_folder()
        self.template = self.workdir + os.path.basename(template)
        self.template_on_procheck_folder = None
    def prepare_folder(self):
        pastadeavaliacao = self.workdir + 'avaliacao_procheck/'
        if os.path.exists(pastadeavaliacao):
	        os.popen('rm -fr '+ pastadeavaliacao)
        os.mkdir(pastadeavaliacao)
        return pastadeavaliacao

    def copy_templates_for_procheck_evaluate(self):
        os.popen('cp '+ self.template +  ' ' + self.procheck_workdir)
        self.template_on_procheck_folder = self.procheck_workdir + os.path.basename(self.template)

    def run_prochek(self):
      script = """\
import os
#path = os.getcwd()
os.chdir('""" + self.procheck_workdir + """')
os.popen('procheck '+ '""" + self.template_on_procheck_folder + """' +  ' ' + str(2.0))
#os.chdir(path)
      """
      script_path = self.procheck_workdir + "procheck.py"
      procheck_script = file(script_path, "w")        
      procheck_script.write(script)
      procheck_script.close()
      os.popen("python " + script_path)
      return self.procheck_workdir[0:-1]       

class Loop_Refinement(object):
    """docstring for Loop_Refinement"""
    def __init__(self, initial_model, start_residue, end_residue):
            self.initial_model = initial_model
            self.start_residue = start_residue
            self.end_residue = end_residue
            self.myscript = ""
    
    def create_script_in_folder(self,path):
        script = """\
# Loop refinement of an existing model
from modeller import *
from modeller.automodel import *
import os

log.verbose()
env = environ()
os.chdir('""" + path + """')

# directories for input atom files
env.io.atom_files_directory = './:../atom_files'

# Create a new class based on 'loopmodel' so that we can redefine
# select_loop_atoms (necessary)
class MyLoop(loopmodel):
    # This routine picks the residues to be refined by loop modeling
    def select_loop_atoms(self):
        # 10 residue insertion 
        return selection(self.residue_range('""" + self.start_residue + """', ' """ + self.end_residue + """'))

m = MyLoop(env,
           inimodel='""" + self.initial_model + """', # initial model of the target
           sequence='seq.ali')          # code of the target

m.loop.starting_model= 1           # index of the first loop model 
m.loop.ending_model  = 5          # index of the last loop model
m.loop.md_level = refine.very_fast # loop refinement method; this yields
                                   # models quickly but of low quality;
                                   # use refine.slow for better models

m.make()
""" 
        script_path = path + os.sep + "loop.py"
        loop_script = file(script_path, "w")        
        loop_script.write(script)
        loop_script.close()
        self.myscript = script_path

    def __folder_of_evaluate__(self):
        pass

    def get_model(self):
        processo = modeller_caller()
        processo.run(self.myscript)
        
    def get_results(self):
        folder = os.path.dirname(self.myscript)
        mof = 0
        filemof = ""
        for files in os.listdir(folder):
            if (files.startswith('seq.ali.BL')):
                    arqr = file(folder + '/' + files, 'r')
                    arqr.readline()
                    linha = arqr.readline()
                    if (mof == 0) or (linha.partition(':      ')[2] < mof):
                            mof = linha.partition(':      ')[2]
                            filemof = folder + '/' + files
                            arqr.close()
        # if not (os.path.exists(folder + '/../loop')):
        #         os.mkdir(folder + '/../loop')
        # os.popen('cp '+ filemof +  ' ' + folder + '/../loop/')
        return filemof

class Malign(object):
    """docstring for Malign"""
    def __init__(self, path):
        self.path = path
        self.myscript = ""

    def create_script_in_folder(self, template, best_sequence, loop_sequence):
        script = """from modeller import *
import os

os.chdir('""" + self.path + """')
log.verbose()
env = environ()

env.io.atom_files_directory = './:../atom_files/'

aln = alignment(env)
for (code, chain) in (('""" + template + """', 'A'), ('""" + best_sequence + """', ''), ('""" + loop_sequence + """', '')):
    mdl = model(env, file=code, model_segment=('FIRST:'+chain, 'LAST:'+chain))
    aln.append_model(mdl, atom_files=code, align_codes=code+chain)

for (weights, write_fit, whole) in (((1., 0., 0., 0., 1., 0.), False, True),
                                    ((1., 0.5, 1., 1., 1., 0.), False, True),
                                    ((1., 1., 1., 1., 1., 0.), True, False)):
    aln.salign(rms_cutoff=3.5, normalize_pp_scores=False,
               rr_file='$(LIB)/as1.sim.mat', overhang=30,
               gap_penalties_1d=(-450, -50),
               gap_penalties_3d=(0, 3), gap_gap_score=0, gap_residue_score=0,
               dendrogram_file='ali.tree',
               alignment_type='tree', # If 'progresive', the tree is not
                                      # computed and all structues will be
                                      # aligned sequentially to the first
               feature_weights=weights, # For a multiple sequence alignment only
                                        # the first feature needs to be non-zero
               improve_alignment=True, fit=True, write_fit=write_fit,
               write_whole_pdb=whole, output='ALIGNMENT QUALITY')

#aln.write(file='ali.pap', alignment_format='PAP')
aln.write(file='ali.ali', alignment_format='PIR')

aln.salign(rms_cutoff=1.0, normalize_pp_scores=False,
           rr_file='$(LIB)/as1.sim.mat', overhang=30,
           gap_penalties_1d=(-450, -50), gap_penalties_3d=(0, 3),
           gap_gap_score=0, gap_residue_score=0, dendrogram_file='1is3A.tree',
           alignment_type='progressive', feature_weights=[0]*6,
           improve_alignment=False, fit=False, write_fit=True,
           write_whole_pdb=False, output='QUALITY')
"""
        script_path = self.path + os.sep + "salign.py"
        loop_script = file(script_path, "w")        
        loop_script.write(script)
        loop_script.close()
        self.myscript = script_path

    def get_model(self):
        processo = modeller_caller()
        processo.run(self.myscript)

class Malign2(object):
    """docstring for Malign"""
    def __init__(self, path):
        self.path = path
        self.myscript = ""

    def create_script_in_folder(self, template, best_sequence):
        script = """from modeller import *
import os

os.chdir('""" + self.path + """')
log.verbose()
env = environ()

env.io.atom_files_directory = './:../atom_files/'

aln = alignment(env)
for (code, chain) in (('""" + template + """', 'A'), ('""" + best_sequence + """', '')):
    mdl = model(env, file=code, model_segment=('FIRST:'+chain, 'LAST:'+chain))
    aln.append_model(mdl, atom_files=code, align_codes=code+chain)

for (weights, write_fit, whole) in (((1., 0., 0., 0., 1., 0.), False, True),
                                    ((1., 0.5, 1., 1., 1., 0.), False, True),
                                    ((1., 1., 1., 1., 1., 0.), True, False)):
    aln.salign(rms_cutoff=3.5, normalize_pp_scores=False,
               rr_file='$(LIB)/as1.sim.mat', overhang=30,
               gap_penalties_1d=(-450, -50),
               gap_penalties_3d=(0, 3), gap_gap_score=0, gap_residue_score=0,
               dendrogram_file='ali.tree',
               alignment_type='tree', # If 'progresive', the tree is not
                                      # computed and all structues will be
                                      # aligned sequentially to the first
               feature_weights=weights, # For a multiple sequence alignment only
                                        # the first feature needs to be non-zero
               improve_alignment=True, fit=True, write_fit=write_fit,
               write_whole_pdb=whole, output='ALIGNMENT QUALITY')

#aln.write(file='ali.pap', alignment_format='PAP')
aln.write(file='ali.ali', alignment_format='PIR')

aln.salign(rms_cutoff=1.0, normalize_pp_scores=False,
           rr_file='$(LIB)/as1.sim.mat', overhang=30,
           gap_penalties_1d=(-450, -50), gap_penalties_3d=(0, 3),
           gap_gap_score=0, gap_residue_score=0, dendrogram_file='1is3A.tree',
           alignment_type='progressive', feature_weights=[0]*6,
           improve_alignment=False, fit=False, write_fit=True,
           write_whole_pdb=False, output='QUALITY')
"""
        script_path = self.path + os.sep + "salign.py"
        loop_script = file(script_path, "w")        
        loop_script.write(script)
        loop_script.close()
        self.myscript = script_path

    def get_model(self):
        processo = modeller_caller()
        processo.run(self.myscript)

class GetProt(object):
    """docstring for GetProt"""
    def __init__(self, loop_folder):
        self.myscript = ""
        self.path = loop_folder

    def create_script_in_folder(self, template,model,myloop):
        template = os.path.basename(template)[0:-4]
        model = os.path.basename(model)[0:-4]
        myloop = os.path.basename(myloop)[0:-4]
        # self.path = os.path.dirname(model)
        script = """import pylab
import modeller
import os

os.chdir('""" + self.path + """')
def get_profile(profile_file, seq):
    '''Read `profile_file` into a Python array, and add gaps corresponding to
       the alignment sequence `seq`.'''
    # Read all non-comment and non-blank lines from the file:
    f = file(profile_file)
    vals = []
    for line in f:
        if not line.startswith('#') and len(line) > 10:
            spl = line.split()
            vals.append(float(spl[-1]))
    # Insert gaps into the profile corresponding to those in seq:
    for n, res in enumerate(seq.residues):
        for gap in range(res.get_leading_gaps()):
            vals.insert(n, None)
    # Add a gap at position '0', so that we effectively count from 1:
    vals.insert(0, None)
    return vals

e = modeller.environ()
a = modeller.alignment(e, file='ali.ali')

template = get_profile('""" + template + """.profile', a['""" + template + """A'])
model = get_profile('""" + model + """.profile', a['""" + model + """'])
myloop  = get_profile('""" + myloop + """.profile', a['""" + myloop + """'])
# Plot the template and model profiles in the same plot for comparison:
pylab.figure(1, figsize=(10,6))
pylab.xlabel('Alignment position')
pylab.ylabel('DOPE per-residue score')
pylab.plot(model, color='red', linewidth=2, label='Model')
pylab.plot(template, color='green', linewidth=2, label='Template')
pylab.plot(myloop, color='blue', linewidth=2, label='Loop refinement')
pylab.legend()
pylab.savefig('dope_profile_loop.png', dpi=65)
"""
        script_path = self.path + os.sep + "plot_profile.py"
        loop_script = file(script_path, "w")        
        loop_script.write(script)
        loop_script.close()
        self.myscript = script_path

    def get_model(self):
        processo = modeller_caller()
        processo.run(self.myscript)

class GetProt2(object):
    """docstring for GetProt"""
    def __init__(self, loop_folder):
        self.myscript = ""
        self.path = loop_folder

    def create_script_in_folder(self, template,model):
        template = os.path.basename(template)[0:-4]
        model = os.path.basename(model)[0:-4]
        # myloop = os.path.basename(myloop)[0:-4]
        # self.path = os.path.dirname(model)
        script = """import pylab
import modeller
import os

os.chdir('""" + self.path + """')
def get_profile(profile_file, seq):
    '''Read `profile_file` into a Python array, and add gaps corresponding to
       the alignment sequence `seq`.'''
    # Read all non-comment and non-blank lines from the file:
    f = file(profile_file)
    vals = []
    for line in f:
        if not line.startswith('#') and len(line) > 10:
            spl = line.split()
            vals.append(float(spl[-1]))
    # Insert gaps into the profile corresponding to those in seq:
    for n, res in enumerate(seq.residues):
        for gap in range(res.get_leading_gaps()):
            vals.insert(n, None)
    # Add a gap at position '0', so that we effectively count from 1:
    vals.insert(0, None)
    return vals

e = modeller.environ()
a = modeller.alignment(e, file='ali.ali')

template = get_profile('""" + template + """.profile', a['""" + template + """A'])
model = get_profile('""" + model + """.profile', a['""" + model + """'])
# Plot the template and model profiles in the same plot for comparison:
pylab.figure(1, figsize=(10,6))
pylab.xlabel('Alignment position')
pylab.ylabel('DOPE per-residue score')
pylab.plot(model, color='red', linewidth=2, label='Model')
pylab.plot(template, color='green', linewidth=2, label='Template')
#pylab.plot(myloop, color='blue', linewidth=2, label='Loop refinement')
pylab.legend()
pylab.savefig('dope_profile_loop.png', dpi=65)
"""
        script_path = self.path + os.sep + "plot_profile.py"
        loop_script = file(script_path, "w")        
        loop_script.write(script)
        loop_script.close()
        self.myscript = script_path

    def get_model(self):
        processo = modeller_caller()
        processo.run(self.myscript)

class MakeProfile(object):
    """docstring for MakeProfiles"""
    def __init__(self):
        pass
    
    def create_script_in_folder(self,pdb_file):
        self.path = os.path.dirname(pdb_file)
        script = """from modeller import *
from modeller.scripts import complete_pdb
import os

os.chdir('""" + self.path + """')
log.verbose()    # request verbose output
env = environ()
env.libs.topology.read(file='$(LIB)/top_heav.lib') # read topology
env.libs.parameters.read(file='$(LIB)/par.lib') # read parameters

# directories for input atom files
env.io.atom_files_directory = './:../atom_files'

# read model file
mdl = complete_pdb(env, '""" + pdb_file + """')

s = selection(mdl)
s.assess_dope(output='ENERGY_PROFILE NO_REPORT', file='""" + os.path.basename(pdb_file)[0:-4] + """.profile',
              normalize_profile=True, smoothing_window=15)
"""
        script_path = self.path + os.sep + "get_profile.py"
        loop_script = file(script_path, "w")        
        loop_script.write(script)
        loop_script.close()
        self.myscript = script_path

    def get_model(self):
        processo = modeller_caller()
        processo.run(self.myscript)

class MakeProfile2(object):
    """docstring for MakeProfiles"""
    def __init__(self):
        pass
    
    def create_script_in_folder(self,pdb_file):
        self.path = os.path.dirname(pdb_file)
        script = """from modeller import *
from modeller.scripts import complete_pdb
import os

os.chdir('""" + self.path + """')
log.verbose()    # request verbose output
env = environ()
env.libs.topology.read(file='$(LIB)/top_heav.lib') # read topology
env.libs.parameters.read(file='$(LIB)/par.lib') # read parameters

# directories for input atom files
env.io.atom_files_directory = './:../atom_files'

# read model file
mdl = complete_pdb(env, '""" + pdb_file + """')

s = selection(mdl)
s.assess_dope(output='ENERGY_PROFILE NO_REPORT', file='""" + os.path.basename(pdb_file)[0:-4] + """.profile',
              normalize_profile=True, smoothing_window=15)
"""
        script_path = self.path + os.sep + "get_profile.py"
        loop_script = file(script_path, "w")        
        loop_script.write(script)
        loop_script.close()
        self.myscript = script_path

    def get_model(self):
        processo = modeller_caller()
        processo.run(self.myscript)


import unittest
import tempfile
from should_dsl import *
from options.Prefs import Prefs

class PrefsTest(unittest.TestCase):
	def setUp(self):
		self.prefs = Prefs()

	def tests_if_prefs_is_an_singleton_class(self):
		new_instance_of_prefs = Prefs() #creates a new instance of press, this instance will have the same value of self.prefs

		key_shared_between_the_instances = "foo"
		value_shared_between_the_instances = "bar"

		self.prefs.set_setting(key_shared_between_the_instances, value_shared_between_the_instances)
		new_instance_of_prefs.myprefs[key_shared_between_the_instances] |should| equal_to(value_shared_between_the_instances)

	def test_if_set_an_setting(self):
		self.prefs.set_setting("teste","teste")
		self.prefs.myprefs["teste"] |should| equal_to("teste")

	def test_if_get_a_setting(self):
		self.prefs.set_setting("foo","bar")
		self.prefs.get_setting("foo") |should| equal_to("bar")



#import rpyc
import tempfile
import os
import time
import modelagem
from file import *
import zipfile
from options.Prefs import Prefs

option = Prefs()
# PDBFolder = "/home/jorgehf/PDB/"
PDBFolder = option.get_setting("PDBFolder")


class ServerService(object):
	"""docstring for ServerService"""
	def __init__(self, arg):
		# super(ServerService, self).__init__()
		self.arg = arg
		self.workdir = tempfile.mkdtemp() + "/"
		print self.workdir

	def exposed_receive_file(self, filename):
		time.sleep(2)
		return open(self.workdir + os.path.basename(filename), "r")

	def exposed_check_serial(self, password):
		if password == "MODELIRANJE":
			return True
		else:
			return False

	def exposed_receive_file(self, filename, buffer_file):
		received_file = file(self.workdir + os.path.basename(filename), "w")
		received_file.write(buffer_file)
		received_file.close()

	def exposed_find_templates(self,serial):
		# self.callback = rpyc.async(callback)
		teste = modelagem.mold(self.workdir + "seq.ali")
		teste.make_build_profilepy()
		teste.find_templates()
		# self.callback("find_templates")

	def exposed_send_file(self, name_of_file):
		sending_file = file(self.workdir + os.path.basename(name_of_file), "r")
		buffer_file = sending_file.load_in_memory()
		sending_file.close()
		return buffer_file

	def exposed_send_template(self, pdb_name):
		pdb_path = PDBFolder + pdb_name + ".pdb"
		pdb_path_CAPS = PDBFolder + pdb_name.upper() + ".pdb"
		# print pdb_path_CAPS
		if os.path.exists(pdb_path):
			sending_file = file(pdb_path, "r")
			buffer_file = sending_file.load_in_memory()
			sending_file.close()
			return buffer_file

		elif os.path.exists(pdb_path_CAPS):
			sending_file = file(pdb_path_CAPS, "r")
			buffer_file = sending_file.load_in_memory()
			sending_file.close()
			return buffer_file
		else:
			raise IOError

	def exposed_align(self,pir_sequence_file,template):
		teste = modelagem.Align(self.workdir, self.workdir, os.path.basename(template),os.path.basename(pir_sequence_file))
		teste.make_readseq_py()
		teste.read_sequence()
		teste.make_align2d_py()
		teste.align_sequence()

	def exposed_model(self, ali_ali, template):
		teste = modelagem.Modeler(self.workdir, self.workdir, os.path.basename(template), os.path.basename(ali_ali))
		teste.make_get_model_py()
		teste.model_sequence()
		best_result = teste.get_results()
		# print 
		return os.path.basename(best_result)

	def exposed_evaluate(self,template,model_file,ali_ali_file):
		# teste = modelagem.Evaluate(template,model_file,ali_ali_file,self.workdir)
		# teste.make_evaluate_model(model_file)
		# teste.get_evaluate()
		# teste.make_evaluate_model(template)
		# teste.get_evaluate()
		# teste.plot_profiles()
		# return  'dope_profile.png'

		# loop_refinament_folder = self.workdir 
		evaluate_folder = self.workdir
		if not os.path.exists(evaluate_folder):
			os.mkdir(evaluate_folder)
		best_model = self.workdir + model_file
		# loop_model = self.workdir + loopmodel
		my_template = self.workdir + template
		# os.popen("cp "+ best_model + " " + loop_val)
		# os.popen("cp "+ loop_model + " " + loop_val)
		# os.popen("cp "+ my_template + " " + loop_val)
		multiple_align = modelagem.Malign2(evaluate_folder)
		multiple_align.create_script_in_folder(os.path.basename(my_template)[0:-4],os.path.basename(best_model)[0:-4])
		multiple_align.get_model()
		profile_best_model = modelagem.MakeProfile()
		profile_best_model.create_script_in_folder(evaluate_folder + os.path.basename(model_file))
		profile_best_model.get_model()
		profile_my_template = modelagem.MakeProfile()
		profile_my_template.create_script_in_folder(evaluate_folder + os.path.basename(template))
		profile_my_template.get_model()
		# profile_loop_model = modelagem.MakeProfile()
		# profile_loop_model.create_script_in_folder(evaluate_folder + os.path.basename(loopmodel))
		# profile_loop_model.get_model()

		plot_profiles = modelagem.GetProt2(evaluate_folder)
		plot_profiles.create_script_in_folder(my_template,best_model)
		plot_profiles.get_model()
		return "dope_profile_loop.png"

	def exposed_evaluatePROCHECK(self, model_file):
		teste = modelagem.Procheck_Evaluate(self.workdir, model_file)
		teste.copy_templates_for_procheck_evaluate()
		procheck_folder = teste.run_prochek()
		zipped_procheck_folder_name = procheck_folder + ".zip"
		zipped_procheck_folder = self.__zipper__(procheck_folder,zipped_procheck_folder_name)
		return os.path.basename(zipped_procheck_folder)

	def __recursive_zip__(self,zipf, directory, folder = ""):
		for item in os.listdir(directory):
			if os.path.isfile(os.path.join(directory, item)):
				zipf.write(os.path.join(directory, item), folder + os.sep + item)
			elif os.path.isdir(os.path.join(directory, item)):
				self.__recursive_zip__(zipf, os.path.join(directory, item), folder + os.sep + item)

	def __zipper__(self,folder,nome_destino):
		zipz = nome_destino
		zipf = zipfile.ZipFile(zipz, "w", compression=zipfile.ZIP_DEFLATED )
		path = folder
		self.__recursive_zip__(zipf, path)
		zipf.close()
		return nome_destino

	def exposed_loopmodel(self,model, start_residue, end_residue):
		teste = modelagem.Loop_Refinement(self.workdir + os.path.basename(model), start_residue, end_residue)
		teste.create_script_in_folder(self.workdir)
		teste.get_model()
		best_result = teste.get_results()
		# print 
		return os.path.basename(best_result)

	def exposed_evaluatelooprefinament(self,template,model_file,loopmodel, ali_ali_file):
   # def __loop_refinament_validation__(self,thread, callback):
		# self.callback = rpyc.async(callback)
		loop_refinament_folder = self.workdir 
		loop_val = loop_refinament_folder # + "loop_val" +loop +  os.sep
		if not os.path.exists(loop_val):
			os.mkdir(loop_val)
		best_model = self.workdir + model_file
		loop_model = self.workdir + loopmodel
		my_template = self.workdir + template
		# os.popen("cp "+ best_model + " " + loop_val)
		# os.popen("cp "+ loop_model + " " + loop_val)
		# os.popen("cp "+ my_template + " " + loop_val)
		multiple_align = modelagem.Malign(loop_val)
		multiple_align.create_script_in_folder(os.path.basename(my_template)[0:-4],os.path.basename(best_model)[0:-4],os.path.basename(loop_model)[0:-4])
		multiple_align.get_model()
		profile_best_model = modelagem.MakeProfile()
		profile_best_model.create_script_in_folder(loop_val + os.path.basename(model_file))
		profile_best_model.get_model()
		profile_my_template = modelagem.MakeProfile()
		profile_my_template.create_script_in_folder(loop_val + os.path.basename(template))
		profile_my_template.get_model()
		profile_loop_model = modelagem.MakeProfile()
		profile_loop_model.create_script_in_folder(loop_val + os.path.basename(loopmodel))
		profile_loop_model.get_model()

		plot_profiles = modelagem.GetProt(loop_val)
		plot_profiles.create_script_in_folder(my_template,best_model,loop_model)
		plot_profiles.get_model()
		return "dope_profile_loop.png"

		# self.dope_profile_loop = "loop/dope_profile.png"
		# self.callback("dope_profile_loop")



#if __name__ == "__main__":
#    from rpyc.utils.server import ThreadedServer
#    t = ThreadedServer(ServerService, port = 18861)
#    t.start()



from ModellingStep import ModellingStep
import os
import wx
from wx.lib.pubsub import Publisher

class ModelStep(ModellingStep):
	"""docstring for ModelStep"""
	def __init__(self, client_instance, workdir, template, ali_ali):
		super(ModelStep, self).__init__(client_instance, workdir)
		self.model = None
		self.__list_of_files_should_send__ = (ali_ali, template)

	def __get_back_new_files__(self):
		self.model = self.workdir + self.model_name
		self.__client_instance__.receive_file(self.model)

	def __run_my_step__(self):
		self.model_name = self.__client_instance__.model(self.__list_of_files_should_send__[0], self.__list_of_files_should_send__[1])

	def run(self):
		try:
			super(ModelStep, self).run()
			wx.CallAfter(Publisher().sendMessage, "OnModelarButtonDone", None)
			
		except Exception, e:
			wx.CallAfter(Publisher().sendMessage, "my_error", ["Nao foi possivel realizar a modelagem. Verifique a integridade do alinhamento e do template.", e])


#Boa:Dialog:SelectAutoModelMode

import wx
from model.AutoModelMode import AutoModelMode
def create(parent):
    return SelectAutoModelMode(parent)

[wxID_SELECTAUTOMODELMODE, wxID_SELECTAUTOMODELMODEBUTTONCANCEL, 
 wxID_SELECTAUTOMODELMODEBUTTONOK, 
 wxID_SELECTAUTOMODELMODERADIOBUTTONCLIENTSERVER, 
 wxID_SELECTAUTOMODELMODERADIOBUTTONOFFLINE, 
 wxID_SELECTAUTOMODELMODESTATICBOX1, wxID_SELECTAUTOMODELMODESTATICTEXT1, 
] = [wx.NewId() for _init_ctrls in range(7)]

class SelectAutoModelMode(wx.Dialog):
    def _init_ctrls(self, prnt):
        # generated method, don't edit
        wx.Dialog.__init__(self, id=wxID_SELECTAUTOMODELMODE,
              name=u'SelectAutoModelMode', parent=prnt, pos=wx.Point(461, 315),
              size=wx.Size(353, 240), style=wx.DEFAULT_DIALOG_STYLE,
              title=u'Select AutoModel Mode')
        self.SetClientSize(wx.Size(353, 240))

        self.radioButtonClientServer = wx.RadioButton(id=wxID_SELECTAUTOMODELMODERADIOBUTTONCLIENTSERVER,
              label=u'Internet Mode', name=u'radioButtonClientServer',
              parent=self, pos=wx.Point(104, 96), size=wx.Size(192, 32),
              style=0)
        self.radioButtonClientServer.SetValue(True)

        self.radioButtonOffline = wx.RadioButton(id=wxID_SELECTAUTOMODELMODERADIOBUTTONOFFLINE,
              label=u'Offline Mode', name=u'radioButtonOffline', parent=self,
              pos=wx.Point(104, 136), size=wx.Size(208, 32), style=0)

        self.staticBox1 = wx.StaticBox(id=wxID_SELECTAUTOMODELMODESTATICBOX1,
              label=u'', name='staticBox1', parent=self, pos=wx.Point(16, 72),
              size=wx.Size(320, 112), style=0)

        self.buttonCancel = wx.Button(id=wxID_SELECTAUTOMODELMODEBUTTONCANCEL,
              label=u'Cancel', name=u'buttonCancel', parent=self,
              pos=wx.Point(56, 200), size=wx.Size(85, 27), style=0)
        self.buttonCancel.Bind(wx.EVT_BUTTON, self.OnButtonCancelButton,
              id=wxID_SELECTAUTOMODELMODEBUTTONCANCEL)

        self.buttonOK = wx.Button(id=wxID_SELECTAUTOMODELMODEBUTTONOK,
              label=u'OK', name=u'buttonOK', parent=self, pos=wx.Point(224,
              200), size=wx.Size(85, 27), style=0)
        self.buttonOK.Bind(wx.EVT_BUTTON, self.OnButtonOKButton,
              id=wxID_SELECTAUTOMODELMODEBUTTONOK)

        self.staticText1 = wx.StaticText(id=wxID_SELECTAUTOMODELMODESTATICTEXT1,
              label=u'AutoModel can be utilized in Internet mode or in offline mode. The offline mode is only available  if all dependencies are installed.',
              name='staticText1', parent=self, pos=wx.Point(8, 8),
              size=wx.Size(336, 64), style=0)

    def __init__(self, parent):
        self._init_ctrls(parent)
        self.automodelMode = AutoModelMode()
        if not self.automodelMode.offline_mode_is_ready():
          self.radioButtonOffline.Enable(False)

    def OnButtonCancelButton(self, event):
        self.Destroy()

    def OnButtonOKButton(self, event):
        if self.radioButtonClientServer.GetValue():
          self.automodelMode.online_mode()
        elif self.radioButtonOffline.GetValue():
          self.automodelMode.offline_mode()
        else:
          pass
        self.Close()

    # def OnSelectAutoModelModeClose(self, event):
    #         self.Destroy()
    #         pass


from change_het_window import ChangeHetWindow
import wx

if __name__ == '__main__':
	app = wx.PySimpleApp()
	# my_window = ChangeHetWindow(None, 1,"tests/change_het_tests/1bdm.pdb")
	my_window = ChangeHetWindow(None, 1,"/tmp/tmprYCqYC/5mdh.pdb")
	my_window.Show()
	app.MainLoop()


import time
import tempfile
import os
import shutil

class server(object):
	"""docstring for server"""
	def __init__(self):
		time.sleep(1)
		self.workdir = tempfile.mkdtemp() + "/"
		print self.workdir


	def check_serial(self, serial):
		time.sleep(1)
		return True

	def receive_file(self, filename, buffer_file):
		received_file = file(self.workdir + os.path.basename(filename), "w")
		received_file.write(buffer_file)
		received_file.close()

	def find_templates(self,serial):
		pass

	def disconnect(self):
		pass




from ModellingStep import ModellingStep
import os
import wx
from wx.lib.pubsub import Publisher
from modellingfile.AlignFile import AlignFile

class AlignStep(ModellingStep):
	"""docstring for AlignStep"""
	def __init__(self, client_instance, workdir, template, pir_sequence_file):
		super(AlignStep, self).__init__(client_instance, workdir)
		self.__list_of_files_should_send__ = (pir_sequence_file, template)
		self.str_seq = None
		self.ali_ali = None
		self.ali_pap = None

	def __get_back_new_files__(self):
		self.str_seq = self.workdir + "str.seq"
		self.ali_ali = self.workdir + "ali.ali"
		# self.ali_pap = self.workdir + "ali.pap"
		self.__client_instance__.receive_file(self.str_seq)
		self.__client_instance__.receive_file(self.ali_ali)
		# self.__client_instance__.receive_file(self.ali_pap)

	def __run_my_step__(self):
		self.__client_instance__.align(self.__list_of_files_should_send__[0], self.__list_of_files_should_send__[1])

	def run(self):
		try:
			super(AlignStep, self).run()
			print "fim deste step"
			self.__normalize_align_file__()
			wx.CallAfter(Publisher().sendMessage, "OnAlinharButtonDone", None)
		except Exception, e:
			wx.CallAfter(Publisher().sendMessage, "my_error", ["Nao foi possivel realizar o alinhamento. Verifique a integridade do Template e da sequencia target.", e])

	def set_my_alignment(self,my_alignment_file):
		self.__copy_file_for_dir__(my_alignment_file, self.workdir + os.path.basename(my_alignment_file))
		self.ali_ali = self.workdir + os.path.basename(my_alignment_file)

	def __normalize_align_file__(self):
		aliali_for_modification = AlignFile(self.ali_ali)
		aliali_for_modification.copy_heteroatoms(0,1)
		aliali_for_modification.write_changes()
		aliali_for_modification.close()


from window.wintools.wintools import *
from modellingfile.residues import *
from modellingfile.AlignFile import *
from modellingfile.pdbfile import *
import os
import sys
class ChangeHetWindow(subwintools):
	"""docstring for ChangeHetWindow"""
	def __init__(self, parent, id,  arquivoentrada):
		self.arquivoentrada = arquivoentrada
		self.Ions = TabelaDeTiposdeResiduos(os.path.dirname(os.path.realpath(sys.argv[0])) + "/Ions.txt")
		self.Cofatores = TabelaDeTiposdeResiduos(os.path.dirname(os.path.realpath(sys.argv[0])) + "/Cofatores.txt")
		self.pdbfile = pdbfile(arquivoentrada)
		self.pulldown_list = {}
		self.alifile = AlignFile(os.path.dirname(arquivoentrada) + "/ali.ali")
		self.Cadeias = self.pdbfile.chains()

		self.button = {} 
		wx.Dialog.__init__(self, parent, id, 'Changing Heteroatom',  size=(550,340))
		panel = wx.Panel(self, -1,  size=(550,340))
		self.panel = panel
		self.statictext = {}
		self.createText(panel)
		self.createMuchButtons(panel)
		self.parent = parent
		self.list_of_pull_downs = self.load_pull_down()

	def textData(self):
		list_of_text_data = [("Use the combobox below to change the heteroatoms of their respective chains.\nLocked combobox are heteroatoms that are not possible to change.", (20, 10))]
		posY = 45
		posYincrement = 40
		for selectedChain in self.Cadeias:
			list_of_text_data.append(("Chain " + selectedChain, (20, posY)))
			posY += posYincrement
		return list_of_text_data

	def list_of_possibles_residues(self, residue):
		if self.Ions.Contem(residue):
			return self.Ions.ListaTotalqueContem(residue)
		elif self.Cofatores.Contem(residue):
			return self.Cofatores.ListaTotalqueContem(residue)

	def symbol_of_residue(self, residue):
		if self.Ions.Contem(residue):
			return self.Ions.SimboloDe(residue)
		elif self.Cofatores.Contem(residue):
			return self.Cofatores.SimboloDe(residue)

	def symbol_of_heteroatom(self, heteroatom):
		if self.Ions.Contem(heteroatom):
			return self.Ions.SimboloDoHeteroatomo(heteroatom)
		elif self.Cofatores.Contem(heteroatom):
			return self.Cofatores.SimboloDoHeteroatomo(heteroatom)

	def residue_of_heteroatom(self, heteroatom):
		if self.Ions.Contem(heteroatom):
			return self.Ions.PossiveisNomes(heteroatom)[0]
		elif self.Cofatores.Contem(heteroatom):
			return self.Cofatores.PossiveisNomes(heteroatom)[0]

	def load_pull_down(self):
		dictionary_of_heteroatoms = {}
		posY = 45
		posYincrement = 40
		posX = 85
		posXincrement = 65
		for selectedChain in self.Cadeias:
			dictionary_of_heteroatoms[selectedChain] = {}
			for selectedHeteroatom in self.pdbfile.HetatomsInChain(selectedChain):
				if self.list_of_possibles_residues(selectedHeteroatom):
					dictionary_of_heteroatoms[selectedChain][selectedHeteroatom] = self.createOnePullDown(self.panel, posX,posY, self.list_of_possibles_residues(selectedHeteroatom))
				else:
					dictionary_of_heteroatoms[selectedChain][selectedHeteroatom] = self.createOnePullDown(self.panel, posX,posY, [selectedHeteroatom])
					dictionary_of_heteroatoms[selectedChain][selectedHeteroatom].Enable(False)
				posX += posXincrement
			posX = 85
			posY += posYincrement
		return dictionary_of_heteroatoms

	def buttonData(self):
		return(("Ok",self.ok, (100,280)),
				("Cancel",self.OnCloseWindow, (12,280)),)


	def ok(self,event):
		for selectedChain in self.Cadeias:
			for selectedHeteroatom in self.pdbfile.HetatomsInChain(selectedChain):	
				if self.list_of_pull_downs[selectedChain][selectedHeteroatom].Enabled:
					selection = self.list_of_pull_downs[selectedChain][selectedHeteroatom].GetStringSelection()

					self.change_heteroatom_of_align(selectedChain,selectedHeteroatom, selection)

					# print selectedHeteroatom + " "+  selection

					self.change_heteroatom_of_pdb(selectedChain, selectedHeteroatom, selection)
		self.alifile.write_changes()
		# self.alifile.__replace_files__()

		self.alifile.close()
		self.pdbfile.write()
		self.pdbfile.close()
		self.Destroy()

		


	def change_heteroatom_of_align(self,chain,heteroatom, string_selection):
		residue = self.get_residue_of_string_selection(string_selection)
		new_heteroatom = self.symbol_of_residue(residue)
		old_heteroatom = self.symbol_of_heteroatom(heteroatom)

		print old_heteroatom + "(" + heteroatom + ")" + "->" + new_heteroatom
		self.alifile.select_sequence(1)
		chain_number = self.Cadeias.index(chain) + 1
		self.alifile.change_heteroatom_of_chain(chain_number,old_heteroatom,new_heteroatom)
		self.alifile.select_sequence(2)
		self.alifile.change_heteroatom_of_chain(chain_number,old_heteroatom,new_heteroatom)

	def change_heteroatom_of_pdb(self,chain,old_heteroatom, new_heteroatom):
		residue = self.get_residue_of_string_selection(new_heteroatom)
		residue = self.residue_of_heteroatom(residue)
		self.pdbfile.ChangeHetatoms(chain,old_heteroatom,residue)

	def get_residue_of_string_selection(self, string_selection):
		return string_selection.split()[-1].replace("(", "").replace(")","")






# -*- coding: iso-8859-1 -*-
import os
from wintools.wintools import *
from modellingfile.PDB2 import *
from modellingfile.seq import *

class AlterarCadeiasEHeteroatomos(subwintools):
    def __init__(self, parent, id,  arquivoentrada, arquivoSeq_Ali):
        self.pdbfile = pdb(arquivoentrada)
        self.arquivoSeq_Ali = arquivoSeq_Ali
        self.PastaModels = os.path.dirname(arquivoentrada)
        self.Chain = self.pdbfile.chains()
        self.Heteroatomos = self.pdbfile.HetatomsInPDB()
        self.listadeChain = {}
        self.listadeChain = self.ListaDeChainEHeteroatomos(self.Chain)
        self.ChainSelecionadas = self.pdbfile.chains()
        self.statictext = {}
        self.NumeroDeMonomeros = 1

        self.listadeheteroatomos = self.Heteroatomos
        self.button = {}
        self.checkbox = {}
        self.radio = {}
        wx.Dialog.__init__(self, parent, id, 'Selecting Chains and Heteroatoms',  size=(self.CalcularOValorXdaJanela(self.Chain),340)) #Cria o frame
        panel = wx.Panel(self, -1,  size=(self.CalcularOValorXdaJanela(self.Chain),340))
        self.createMuchButtons(panel)
        panel.SetBackgroundColour("LightGray")
        self.createManyRadios(panel)
        self.createCheckBox(panel)
        self.createText(panel)
        self.parent = parent
    def replicarSequencia(self, arquivoSeq_Ali, numerodevezes):
        seq = sequencia(arquivoSeq_Ali, 1)
        arquivoSeq_AliNovo = file(os.path.dirname(arquivoSeq_Ali) + os.sep + "seq.ali2",  "w")
        for i in range(0, seq.tamanho()):
            if i != 2: #onde esta a sequencia
                arquivoSeq_AliNovo.write(seq.conteudodasequencia()[i])
            else:
                  arquivoSeq_AliNovo.write((numerodevezes-1)*(seq.conteudodasequencia()[i][0:len(seq.conteudodasequencia()[2])-1]+ os.sep)+(seq.conteudodasequencia()[i]))
        arquivoSeq_AliNovo.close()
        os.rename(arquivoSeq_Ali, arquivoSeq_Ali + ".old" )
        os.rename(os.path.dirname(arquivoSeq_Ali) + os.sep + "seq.ali2", arquivoSeq_Ali)

    def textData(self):#labels
        return(("Select the chains and heteroatoms", (20, 10)), ("to be used in alignment:", (20, 23)))

    def ListaDeChainEHeteroatomos(self, Chain):
        DicionarioDeChainComHetereoatmos = {}
        for eachChain in Chain:
            Lista = self.pdbfile.HetatomsInChain(eachChain)
            DicionarioDeChainComHetereoatmos[eachChain] = Lista
        return DicionarioDeChainComHetereoatmos

    def CalcularOValorXdaJanela(self,  Chain):
        return(280+140*len(Chain))

    def buttonData(self):
        return(("Ok",self.ok, (self.CalcularOValorXdaJanela(self.Chain)-100,280)),
                    ("Cancel",self.Cancelar, (self.CalcularOValorXdaJanela(self.Chain)-200,280)) )
    def radioData(self):
        return(("Monomer",  (self.CalcularOValorXdaJanela(self.Chain)-400, 270)), ("Dimer",  (self.CalcularOValorXdaJanela(self.Chain)-300, 270)), ("Trimer",  (self.CalcularOValorXdaJanela(self.Chain)-400, 290)), ("Tetramer",  (self.CalcularOValorXdaJanela(self.Chain)-300, 290)) )

    def checkboxdata(self):
        Lista = []
        posX = 40
        Lista.append(('Chain',  self.Chain, (posX, 50),   self.checkboxChain))
        for eachChain in self.Chain:
            heteroatomos = self.pdbfile.HetatomsInChain(eachChain)
            nome = "Chain " + eachChain
            posX = posX + 100
            Lista.append((nome,  heteroatomos, (posX,  50),  self.checkboxheteroatomo))
        return(Lista)

    def createCheckBox(self, panel):
            for eachList in self.checkboxdata():
                posX = eachList[2][0]
                posY = eachList[2][1]
                posYold = posY
                check = {}
                for eachElemento in eachList[1]:
                    posY = posY + 30;
                    check[eachElemento] = self.buidOneCheckbox(panel,  eachElemento,  posX+len(eachList[0]),  posY)
                    check[eachElemento].SetValue(True)
                    self.Bind(wx.EVT_CHECKBOX,  eachList[3], check[eachElemento] )
                if eachList[0] != "Chain":
                    self.checkbox[eachList[0]] = check

                wx.StaticBox(panel,  -1, eachList[0], (posX, posYold), (len(eachList[0])*12, posY-posYold+28))

    def buidOneCheckbox(self, panel,  Elemento,  posX,  posY):
            checkbox = wx.CheckBox(panel,  -1,  Elemento,  (posX ,  posY))
            return checkbox
    def checkboxChain(self, event):
        NomeDaCheckbox = 'Chain ' + event.GetEventObject().GetLabel()
        if(event.IsChecked()):
            self.ChainSelecionadas.append(event.GetEventObject().GetLabel())
            for eachHeteroatomo in self.checkbox[NomeDaCheckbox]:
                 self.checkbox[NomeDaCheckbox][eachHeteroatomo].Enable(True)
        else:
            self.ChainSelecionadas.remove(event.GetEventObject().GetLabel())
            for eachHeteroatomo in self.checkbox[NomeDaCheckbox]:
                self.checkbox[NomeDaCheckbox][eachHeteroatomo].Enable(False)
    def checkboxheteroatomo(self,  event):
           for eachChain in self.Chain:
                Nome = "Chain " + eachChain
                for eachHeteroatomo in self.checkbox[Nome]:
                    if (event.GetEventObject() == self.checkbox[Nome][eachHeteroatomo]):
                        if(event.IsChecked()):
                            self.listadeChain[eachChain].append(eachHeteroatomo)
                        else:
                            self.listadeChain[eachChain].remove(eachHeteroatomo)
    def ok(self,panel):
        if(self.ChainSelecionadas != []):
            pdbnovo = self.pdbfile.const(self.listadeChain,  self.ChainSelecionadas)
            arq = file(self.pdbfile.Nome()  , 'w')
            arq.write(pdbnovo)
            arq.close()
            self.replicarSequencia(self.arquivoSeq_Ali, self.NumeroDeMonomeros)

            self.Destroy()
        else:
            print("ExcecaoLR")
    def Cancelar(self, event):
        self.Destroy()
    def OnRadio(self, event):
        NomeDoRadio = event.GetEventObject().GetLabel()
        if NomeDoRadio == "Monomer":
            self.NumeroDeMonomeros = 1
        elif NomeDoRadio == "Dimer":
            self.NumeroDeMonomeros = 2
        elif NomeDoRadio == "Trimer":
            self.NumeroDeMonomeros = 3
        else:
            self.NumeroDeMonomeros = 4



# if __name__ == '__main__':
#    app = wx.PySimpleApp()
#    frame = AlterarChainEHeteroatomos(None,-1,  "/tmp/tmpx6oilt/1myn.pdb","/tmp/tmpx6oilt/seq.ali")
#    frame.Show()
#    app.MainLoop()




#Boa:Dialog:modelar_sem_alinhar

import wx

def create(parent):
    return modelar_sem_alinhar(parent)

[wxID_MODELAR_SEM_ALINHAR, wxID_MODELAR_SEM_ALINHARBUTTONALINHAMENTO, 
 wxID_MODELAR_SEM_ALINHARBUTTONCANCELAR, wxID_MODELAR_SEM_ALINHARBUTTONOK, 
 wxID_MODELAR_SEM_ALINHARBUTTONPDB, wxID_MODELAR_SEM_ALINHARSTATICTEXT1, 
 wxID_MODELAR_SEM_ALINHARSTATICTEXT2, wxID_MODELAR_SEM_ALINHARSTATICTEXT3, 
 wxID_MODELAR_SEM_ALINHARTEXTCTRLALINHAMENTO, 
 wxID_MODELAR_SEM_ALINHARTEXTCTRLPDB, 
] = [wx.NewId() for _init_ctrls in range(10)]

class modelar_sem_alinhar(wx.Dialog):
    def _init_ctrls(self, prnt):
        # generated method, don't edit
        wx.Dialog.__init__(self, id=wxID_MODELAR_SEM_ALINHAR,
              name=u'modelar_sem_alinhar', parent=prnt, pos=wx.Point(473, 329),
              size=wx.Size(525, 189), style=wx.DEFAULT_DIALOG_STYLE,
              title=u'Modelar Template')
        self.SetClientSize(wx.Size(525, 189))

        self.buttonPDB = wx.Button(id=wxID_MODELAR_SEM_ALINHARBUTTONPDB,
              label=u'Open...', name=u'buttonPDB', parent=self,
              pos=wx.Point(432, 40), size=wx.Size(85, 32), style=0)
        self.buttonPDB.Bind(wx.EVT_BUTTON, self.OnButtonPDBButton,
              id=wxID_MODELAR_SEM_ALINHARBUTTONPDB)

        self.buttonAlinhamento = wx.Button(id=wxID_MODELAR_SEM_ALINHARBUTTONALINHAMENTO,
              label=u'Open...', name=u'buttonAlinhamento', parent=self,
              pos=wx.Point(432, 88), size=wx.Size(85, 32), style=0)
        self.buttonAlinhamento.Bind(wx.EVT_BUTTON,
              self.OnButtonAlinhamentoButton,
              id=wxID_MODELAR_SEM_ALINHARBUTTONALINHAMENTO)

        self.buttonOK = wx.Button(id=wxID_MODELAR_SEM_ALINHARBUTTONOK,
              label=u'OK', name=u'buttonOK', parent=self, pos=wx.Point(280,
              152), size=wx.Size(85, 32), style=0)
        self.buttonOK.Bind(wx.EVT_BUTTON, self.OnButtonOKButton,
              id=wxID_MODELAR_SEM_ALINHARBUTTONOK)

        self.buttonCancelar = wx.Button(id=wxID_MODELAR_SEM_ALINHARBUTTONCANCELAR,
              label=u'Cancel', name=u'buttonCancelar', parent=self,
              pos=wx.Point(180, 152), size=wx.Size(85, 31), style=0)
        self.buttonCancelar.Bind(wx.EVT_BUTTON, self.OnButtonCancelarButton,
              id=wxID_MODELAR_SEM_ALINHARBUTTONCANCELAR)

        self.textCtrlPDB = wx.TextCtrl(id=wxID_MODELAR_SEM_ALINHARTEXTCTRLPDB,
              name=u'textCtrlPDB', parent=self, pos=wx.Point(96, 40),
              size=wx.Size(328, 32), style=0, value=u'')

        self.textCtrlAlinhamento = wx.TextCtrl(id=wxID_MODELAR_SEM_ALINHARTEXTCTRLALINHAMENTO,
              name=u'textCtrlAlinhamento', parent=self, pos=wx.Point(96, 88),
              size=wx.Size(328, 32), style=0, value=u'')

        self.staticText1 = wx.StaticText(id=wxID_MODELAR_SEM_ALINHARSTATICTEXT1,
              label=u'To make modelling is necessary of Template in the PDB format and of alignment file.',
              name='staticText1', parent=self, pos=wx.Point(8, 8),
              size=wx.Size(504, 40), style=0)

        self.staticText2 = wx.StaticText(id=wxID_MODELAR_SEM_ALINHARSTATICTEXT2,
              label=u'PDB:', name='staticText2', parent=self, pos=wx.Point(8,
              48), size=wx.Size(29, 15), style=0)

        self.staticText3 = wx.StaticText(id=wxID_MODELAR_SEM_ALINHARSTATICTEXT3,
              label=u'Alingment:', name='staticText3', parent=self,
              pos=wx.Point(8, 96), size=wx.Size(81, 15), style=0)

    def __init__(self, parent):
        # self.parent = parent
        self._init_ctrls(parent)
        # self.client_instance = client_instance
        self.ok = False

    def OnButtonPDBButton(self, event):
        arquivo_do_pdb = wx.FileSelector("Select the template in PDB format", default_path="", default_filename="", default_extension="", wildcard="*.pdb", flags=0, parent=None, x=-1, y=-1)
        self.textCtrlPDB.SetValue(arquivo_do_pdb)

    def OnButtonAlinhamentoButton(self, event):
        arquivo_de_alinhamento = wx.FileSelector("Select the alignment file", default_path="", default_filename="", default_extension="", wildcard="*.*", flags=0, parent=None, x=-1, y=-1)
        self.textCtrlAlinhamento.SetValue(arquivo_de_alinhamento)

    def OnButtonOKButton(self, event):
        # self.client_instance.connect_with_server()
        # self.client_instance.send_pdb_file_for_the_server2(self.textCtrlPDB.GetValue())
        # self.client_instance.copy_file_in(self.textCtrlAlinhamento.GetValue(), self.client_instance.get_workdir() + "models/ali.ali")
        # self.client_instance.checkpoint = "align_templates"
        # self.parent.MudarHeteroatomo.Enable(True)
        # self.parent.Modelar.Enable(True)
        # self.parent.default_pathway_modelar = False
        self.alignment_filename = self.textCtrlAlinhamento.GetValue()
        self.template_filename = self.textCtrlPDB.GetValue()
        self.ok = True
        self.Close()

    def OnButtonCancelarButton(self, event):
        self.Close()

    def get_alignment_filename(self):
        return self.alignment_filename

    def get_template_filename(self):
        return self.template_filename


#Boa:MiniFrame:SelectAutoModelMode


import wx
from model.AutoModelMode import AutoModelMode
from options.Prefs import Prefs

def create(parent):
    return SelectAutoModelMode(parent)

[wxID_SELECTAUTOMODELMODE, wxID_SELECTAUTOMODELMODEBUTTONOK, 
 wxID_SELECTAUTOMODELMODECANCELBUTTON, 
 wxID_SELECTAUTOMODELMODERADIOBUTTONCLIENTMODE, 
 wxID_SELECTAUTOMODELMODERADIOBUTTONOFFLINEMODE, 
 wxID_SELECTAUTOMODELMODESTATICBOX1, 
] = [wx.NewId() for _init_ctrls in range(6)]

class SelectAutoModelMode(wx.MiniFrame):
    def _init_ctrls(self, prnt):
        # generated method, don't edit
        wx.MiniFrame.__init__(self, id=wxID_SELECTAUTOMODELMODE,
              name=u'SelectAutoModelMode', parent=prnt, pos=wx.Point(523, 420),
              size=wx.Size(400, 150), style=wx.DEFAULT_FRAME_STYLE,
              title=u'Select the AutoModel Mode')
        self.SetClientSize(wx.Size(400, 150))

        self.staticBox1 = wx.StaticBox(id=wxID_SELECTAUTOMODELMODESTATICBOX1,
              label=u'Select AutoModel Mode:', name='staticBox1', parent=self,
              pos=wx.Point(0, 0), size=wx.Size(400, 150), style=0)

        self.radioButtonClientMode = wx.RadioButton(id=wxID_SELECTAUTOMODELMODERADIOBUTTONCLIENTMODE,
              label=u'Client Mode', name=u'radioButtonClientMode', parent=self,
              pos=wx.Point(136, 56), size=wx.Size(107, 21), style=0)
        self.radioButtonClientMode.SetValue(True)
        self.radioButtonClientMode.Bind(wx.EVT_RADIOBUTTON,
              self.OnRadioButton1Radiobutton,
              id=wxID_SELECTAUTOMODELMODERADIOBUTTONCLIENTMODE)

        self.radioButtonOfflineMode = wx.RadioButton(id=wxID_SELECTAUTOMODELMODERADIOBUTTONOFFLINEMODE,
              label=u'Offline Mode', name=u'radioButtonOfflineMode',
              parent=self, pos=wx.Point(136, 80), size=wx.Size(107, 21),
              style=0)
        self.radioButtonOfflineMode.SetValue(False)
        self.radioButtonOfflineMode.Bind(wx.EVT_RADIOBUTTON,
              self.OnRadioButton2Radiobutton,
              id=wxID_SELECTAUTOMODELMODERADIOBUTTONOFFLINEMODE)

        self.buttonOk = wx.Button(id=wxID_SELECTAUTOMODELMODEBUTTONOK,
              label=u'Ok', name=u'buttonOk', parent=self, pos=wx.Point(192,
              116), size=wx.Size(85, 27), style=0)
        self.buttonOk.Bind(wx.EVT_BUTTON, self.OnButtonOkButton,
              id=wxID_SELECTAUTOMODELMODEBUTTONOK)

        self.cancelButton = wx.Button(id=wxID_SELECTAUTOMODELMODECANCELBUTTON,
              label=u'Cancel', name=u'cancelButton', parent=self,
              pos=wx.Point(88, 116), size=wx.Size(85, 27), style=0)
        self.cancelButton.Bind(wx.EVT_BUTTON, self.OnCancelButtonButton,
              id=wxID_SELECTAUTOMODELMODECANCELBUTTON)

    def __init__(self, parent):
        self._init_ctrls(parent)
        self.myMode = AutoModelMode()

    def OnRadioButton1Radiobutton(self, event):
        event.Skip()

    def OnRadioButton2Radiobutton(self, event):
        event.Skip()

    def OnButtonOkButton(self, event):
        if self.radioButtonClientMode:
            self.myMode.online_mode()
        else:
            self.myMode.offline_mode()

    def OnCancelButtonButton(self, event):
        self.myMode.offline_mode()


import os
class Prefs(object):
	"""docstring for Prefs"""
	
	def __init__(self):
		self.myprefs = {
		"ServerIP" : "200.20.229.25",
		#"ServerIP" : "127.0.0.1",
		# "ServerIP" : "192.168.0.103",
		"ServerPort" : 18861,
		"Online" : True,
		"PDBFolder" : os.getenv("HOME") + "/pdb/",

		}

	def __new__(cls, *args, **kwargs): #Implements a singleton class.
		if not hasattr(cls, '_instance'):
			cls._instance = super(Prefs, cls).__new__(cls, *args, **kwargs)
		return cls._instance

	def get_setting(self, setting_name):
		return self.myprefs[setting_name]

	def set_setting(self, setting_name, data):
		self.myprefs[setting_name] = data
		



#Boa:Dialog:alinhar_sequencia_sem_buscar_template

import wx
import os

def create(parent):
    return alinhar_sequencia_sem_buscar_template(parent)

[wxID_ALINHAR_SEQUENCIA_SEM_BUSCAR_TEMPLATE, 
 wxID_ALINHAR_SEQUENCIA_SEM_BUSCAR_TEMPLATEBUTTONCANCELAR, 
 wxID_ALINHAR_SEQUENCIA_SEM_BUSCAR_TEMPLATEBUTTONOK, 
 wxID_ALINHAR_SEQUENCIA_SEM_BUSCAR_TEMPLATEBUTTONPDB, 
 wxID_ALINHAR_SEQUENCIA_SEM_BUSCAR_TEMPLATEBUTTONSEQUENCIA, 
 wxID_ALINHAR_SEQUENCIA_SEM_BUSCAR_TEMPLATESTATICTEXT1, 
 wxID_ALINHAR_SEQUENCIA_SEM_BUSCAR_TEMPLATESTATICTEXTPDB, 
 wxID_ALINHAR_SEQUENCIA_SEM_BUSCAR_TEMPLATESTATICTEXTSEQUENCIA, 
 wxID_ALINHAR_SEQUENCIA_SEM_BUSCAR_TEMPLATETEXTCTRLPDB, 
 wxID_ALINHAR_SEQUENCIA_SEM_BUSCAR_TEMPLATETEXTCTRLSEQUENCIA, 
] = [wx.NewId() for _init_ctrls in range(10)]

class alinhar_sequencia_sem_buscar_template(wx.Dialog):
    def _init_ctrls(self, prnt):
        # generated method, don't edit
        wx.Dialog.__init__(self, id=wxID_ALINHAR_SEQUENCIA_SEM_BUSCAR_TEMPLATE,
              name=u'alinhar_sequencia_sem_buscar_template', parent=prnt,
              pos=wx.Point(622, 371), size=wx.Size(521, 173),
              style=wx.DEFAULT_DIALOG_STYLE, title=u'Alinhar sequencia')
        self.SetClientSize(wx.Size(521, 173))

        self.staticText1 = wx.StaticText(id=wxID_ALINHAR_SEQUENCIA_SEM_BUSCAR_TEMPLATESTATICTEXT1,
              label=u'To make the alignment is necessary of the user sequence in FASTA format and the template protein in PDB format.',
              name='staticText1', parent=self, pos=wx.Point(16, 8),
              size=wx.Size(504, 32), style=0)

        self.textCtrlSequencia = wx.TextCtrl(id=wxID_ALINHAR_SEQUENCIA_SEM_BUSCAR_TEMPLATETEXTCTRLSEQUENCIA,
              name=u'textCtrlSequencia', parent=self, pos=wx.Point(104, 40),
              size=wx.Size(264, 33), style=0, value=u'')
        self.textCtrlSequencia.SetEditable(False)

        self.textCtrlPDB = wx.TextCtrl(id=wxID_ALINHAR_SEQUENCIA_SEM_BUSCAR_TEMPLATETEXTCTRLPDB,
              name=u'textCtrlPDB', parent=self, pos=wx.Point(104, 80),
              size=wx.Size(264, 33), style=0, value=u'')
        self.textCtrlPDB.SetEditable(False)

        self.buttonSequencia = wx.Button(id=wxID_ALINHAR_SEQUENCIA_SEM_BUSCAR_TEMPLATEBUTTONSEQUENCIA,
              label=u'Open...', name=u'buttonSequencia', parent=self,
              pos=wx.Point(376, 42), size=wx.Size(85, 27), style=0)
        self.buttonSequencia.Bind(wx.EVT_BUTTON, self.OnButtonSequenciaButton,
              id=wxID_ALINHAR_SEQUENCIA_SEM_BUSCAR_TEMPLATEBUTTONSEQUENCIA)

        self.buttonPDB = wx.Button(id=wxID_ALINHAR_SEQUENCIA_SEM_BUSCAR_TEMPLATEBUTTONPDB,
              label=u'Open...', name=u'buttonPDB', parent=self,
              pos=wx.Point(376, 83), size=wx.Size(85, 27), style=0)
        self.buttonPDB.Bind(wx.EVT_BUTTON, self.OnButtonPDBButton,
              id=wxID_ALINHAR_SEQUENCIA_SEM_BUSCAR_TEMPLATEBUTTONPDB)

        self.staticTextSequencia = wx.StaticText(id=wxID_ALINHAR_SEQUENCIA_SEM_BUSCAR_TEMPLATESTATICTEXTSEQUENCIA,
              label=u'Target Seq.:', name=u'staticTextSequencia', parent=self,
              pos=wx.Point(5, 48), size=wx.Size(100, 15), style=0)

        self.staticTextPDB = wx.StaticText(id=wxID_ALINHAR_SEQUENCIA_SEM_BUSCAR_TEMPLATESTATICTEXTPDB,
              label=u'PDB: ', name=u'staticTextPDB', parent=self,
              pos=wx.Point(28, 88), size=wx.Size(33, 15), style=0)

        self.buttonCancelar = wx.Button(id=wxID_ALINHAR_SEQUENCIA_SEM_BUSCAR_TEMPLATEBUTTONCANCELAR,
              label=u'Cancel', name=u'buttonCancelar', parent=self,
              pos=wx.Point(112, 120), size=wx.Size(85, 27), style=0)
        self.buttonCancelar.Bind(wx.EVT_BUTTON, self.OnButtonCancelarButton,
              id=wxID_ALINHAR_SEQUENCIA_SEM_BUSCAR_TEMPLATEBUTTONCANCELAR)

        self.buttonOK = wx.Button(id=wxID_ALINHAR_SEQUENCIA_SEM_BUSCAR_TEMPLATEBUTTONOK,
              label=u'OK', name=u'buttonOK', parent=self, pos=wx.Point(328,
              120), size=wx.Size(85, 27), style=0)
        self.buttonOK.Bind(wx.EVT_BUTTON, self.OnButtonOKButton,
              id=wxID_ALINHAR_SEQUENCIA_SEM_BUSCAR_TEMPLATEBUTTONOK)

    def __init__(self,parent):
        self._init_ctrls(parent)
        # self.client_instance = client_instance
        # self.parent = parent
        self.ok = False

    def OnButtonSequenciaButton(self, event):
        arquivo_da_sequencia = wx.FileSelector("Select the your (target) sequence", default_path="", default_filename="", default_extension="", wildcard="*.*", flags=0, parent=None, x=-1, y=-1)
        self.textCtrlSequencia.SetValue(arquivo_da_sequencia)

    def OnButtonPDBButton(self, event):
        arquivo_do_pdb = wx.FileSelector("Select the PDB of template protein", default_path="", default_filename="", default_extension="", wildcard="*.pdb", flags=0, parent=None, x=-1, y=-1)
        self.textCtrlPDB.SetValue(arquivo_do_pdb)

    def OnButtonCancelarButton(self, event):
        self.Close()

    def OnButtonOKButton(self, event):
        self.sequence_filename = self.textCtrlSequencia.GetValue()
        # self.parent.ModificarTemplate.Enable(True)
        # self.parent.Alinhar.Enable(True)
        self.template_filename  = self.textCtrlPDB.GetValue()
        self.ok = True
        # self.parent.default_pathway_alinhar = False
        self.Close()

    def get_sequence_filename(self):
        return self.sequence_filename

    def get_template_filename(self):
        return self.template_filename



if __name__ == '__main__':
  pass



#Boa:MiniFrame:AlignmentEditorWindow

import wx
import wx.richtext

def create(parent):
    return AlignmentEditorWindow(parent)

[wxID_ALIGNMENTEDITORWINDOW, wxID_ALIGNMENTEDITORWINDOWBUTTONSAVE, 
 wxID_ALIGNMENTEDITORWINDOWTEXTCTRLOFALIGNMENT, 
] = [wx.NewId() for _init_ctrls in range(3)]

class AlignmentEditorWindow(wx.MiniFrame):
    def _init_ctrls(self, prnt):
        # generated method, don't edit
        wx.MiniFrame.__init__(self, id=wxID_ALIGNMENTEDITORWINDOW,
              name=u'AlignmentEditorWindow', parent=prnt, pos=wx.Point(368,
              209), size=wx.Size(707, 482), style=wx.DEFAULT_FRAME_STYLE,
              title=u'Alignment Editor')
        self.SetClientSize(wx.Size(707, 482))

        self.TextCtrlOfAlignment = wx.richtext.RichTextCtrl(id=wxID_ALIGNMENTEDITORWINDOWTEXTCTRLOFALIGNMENT,
              parent=self, pos=wx.Point(0, 48), size=wx.Size(712, 432),
              style=wx.richtext.RE_MULTILINE, value=u'')
        self.TextCtrlOfAlignment.SetLabel(u'')
        self.TextCtrlOfAlignment.SetAutoLayout(False)
        self.TextCtrlOfAlignment.SetName(u'TextCtrlOfAlignment')

        self.ButtonSave = wx.Button(id=wxID_ALIGNMENTEDITORWINDOWBUTTONSAVE,
              label=u'Save...', name=u'ButtonSave', parent=self,
              pos=wx.Point(10, 12), size=wx.Size(85, 27), style=0)

    def __init__(self, parent):
        self._init_ctrls(parent)



from ModellingStep import *
import os,tempfile

class PrepareBeforeStartModelling(ModellingStep):
	"""docstring for LoadMySequenceStep"""
	def __init__(self):
		self.myworkdir = self.__prepare_workdir__()
		print self.myworkdir

	def __prepare_workdir__(self):
		return tempfile.mkdtemp() + os.path.sep

	def get_workdir(self):
		return self.myworkdir

	# def load_fasta_file(self, fasta_file):
	# 	pass

		


class Sequence:
    def __init__(self,sequence_file):
        self.sequence_file = self.load_file_into_memory(sequence_file)

    def structures_names(self):
            file_in_tuple = self.sequence_file.splitlines()
            structures_list = []
            for eachline in file_in_tuple:
                if eachline.startswith('>P1;'):
                    struct = eachline[4:len(eachline)]
                    structures_list.append(struct)
            return structures_list
    def getStrname(self,number):
        if len(self.structures_names()[number]) == 5:
            return self.structures_names()[number][0:-1]
        else:
            return self.structures_names()[number]
                    
        
#        if(os.path.exists(arquivo)):
#          arqr = file(arquivo, 'r')
#          xtrs = ""
#          while True:
#            line = arqr.readline()
#            if (line.startswith('>P1;') and not line.startswith('>P1;seq.ali')): #cuidado structure:
#                i = 4 #CUIDADO i = 10
#                if(xtrs != ""):
#                    xtrs = xtrs + ','
#                while(line[i] != '\n'): #cuidado :
#                    xtrs = xtrs + line[i]
#                    i = i + 1
#            if len(line) == 0:
#                break
#          arqr.close() 
#          return xtrs

    def load_file_into_memory(self,arq):
        try:
            arquivo = open(arq,"rb")
        except IOError:
            print "Erro ao abrir o arquivo"
        arquivo.seek(0,2)
        tamanho = arquivo.tell()
        arquivo.seek(0)
        buffer = arquivo.read(tamanho)
        arquivo.close()
        return buffer

#x = Sequence("/tmp/tmphtU2mm/models/ali.ali")
#print x.structures_names()
#print x.getStrname(0)
        



import subprocess 
import platform
import os
import shutil
# from window.AlignmentEditorWindow import AlignmentEditorWindow

class Clientold(object):
    def open_txt_file(self,filename):
  #       if platform.system() == 'Windows':
  #           subprocess.Popen(["write.exe", filename])
  #       if platform.system() == 'Linux':
  #           if 'DESKTOP_SESSION' in os.environ:
  #               if os.environ['DESKTOP_SESSION'] == 'gnome':
  #                   subprocess.Popen(["gedit", filename])
		# else:
		#     subprocess.Popen(["gedit", filename])
		template_load_window = AlignmentEditorWindow(self)
		template_load_window.Show()

    def save_result_in(self,pathname, to_pathname):
        shutil.copyfile(pathname,to_pathname)

    def copy_file_in(self,path_of_file,distination):
        shutil.copyfile(path_of_file, distination)

    def open_result(self, pathname):
        if platform.system() == 'Windows':
            subprocess.Popen(os.environ['PROGRAMFILES'] + os.sep + 'University of Illinois\\VMD' + os.sep + 'vmd.exe ' + pathname)
        if platform.system() == 'Linux':
            subprocess.Popen(["vmd", pathname])

    def open_procheck_folder(self, myfolder):
        if platform.system() == 'Windows':
            subprocess.Popen(['explorer.exe', myfolder])
        if platform.system() == 'Linux':
            if 'DESKTOP_SESSION' in os.environ:
		subprocess.Popen(['nemo', myfolder])
                if os.environ['DESKTOP_SESSION'] == 'gnome':
                    subprocess.Popen(['nemo', myfolder])
            else:
                subprocess.Popen(['dolphin', myfolder])
        else:
            subprocess.Popen(['nemo', myfolder])

    def open_plot_profile(self,pathname):
        if platform.system() == 'Windows':
            subprocess.Popen(os.environ['PROGRAMFILES'] + os.sep + 'internet explorer' + os.sep + 'iexplore.exe ' + self.path_of_file("dope_profile"))
        if platform.system() == 'Linux':
            if 'DESKTOP_SESSION' in os.environ:
                if os.environ['DESKTOP_SESSION'] == 'gnome':
                    subprocess.Popen(["eog", pathname])
		else:
		    subprocess.Popen(["eog", pathname])

    # def open_plot_profile_loop(self):
    #     if platform.system() == 'Windows':
    #         subprocess.Popen(os.environ['PROGRAMFILES'] + os.sep + 'internet explorer' + os.sep + 'iexplore.exe ' + self.path_of_file("dope_profile_loop"))
    #     if platform.system() == 'Linux':
    #         if 'DESKTOP_SESSION' in os.environ:
    #             if os.environ['DESKTOP_SESSION'] == 'gnome':
    #                 subprocess.Popen(["eog" , self.path_of_file("dope_profile_loop")])
    #             if os.environ['DESKTOP_SESSION'] == 'default':
    #                 subprocess.Popen(["eog" , self.path_of_file("dope_profile_loop")])
    #     else:
    #         subprocess.Popen(["eog" , self.path_of_file("dope_profile_loop")])

    def open_in_other_editor(self,editor, arquivo):
        subprocess.Popen([editor, arquivo])

    def save_myloop_in(self,pathname):
        shutil.copyfile(self.path_of_file("myloop"),pathname)



#!/usr/bin/env python
#Boa:App:BoaApp

import wx

import window.main_window as main_window

modules ={u'main_window': [1, 'Main frame of Application', u'main_window.py'],
 'sequece_window': [0, '', u'sequece_window.py'],
 u'alinhar_window': [0, '', u'alinhar_window.py'],
 u'loop_window': [0, '', u'loop_window.py'],
 u'modelar_window': [0, '', u'modelar_window.py']}

class BoaApp(wx.App):
    def OnInit(self):
        self.main = main_window.create(None)
        self.main.Show()
        self.SetTopWindow(self.main)
        return True

def main():
    application = BoaApp(0)
    application.MainLoop()

if __name__ == '__main__':
    main()



import wx
import time

class AutoModelError(object):
	"""docstring for AutoModelError"""
	def __init__(self, error_msg):
		wx.MessageBox(error_msg, 'Oops', wx.OK | wx.ICON_ERROR)

	def log(self, mensage):
		error_log = file("error_log.txt", "a")
		error_log_msg = str(time.localtime().tm_mday)+"/"+str(time.localtime().tm_mon)+"/"+str(time.localtime().tm_year)+" "+str(time.localtime().tm_hour)+":"+str(time.localtime().tm_min)+":"+str(time.localtime().tm_sec)+" "+str(mensage)+"\n"
		# error_log.write(mensage)      
		# traceback.print_exception(etype, value, etraceback,limit=2, file=error_log)
		error_log.write("----------\n")
		error_log.close()



# -*- coding: utf-8 -*-
from setuptools import setup, Extension

setup(
    name='automodel',

    version='0.5.6',

    # url='https://bitbucket.org/jlalmeidaf/automodel-server-with-hmmer',
    license='',
    author='João Luiz de Almeida Filho, Jorge Hernandez Fernandez',
    author_email='joaoluiz.af@gmail.com',
    keywords='protein modeling modeller automodel',
    description=u'Client of service for structure protein prediction',
    packages=['automodelexception', 'manual', 'MiniServer', 'model', 'modellingfiles', 'modellingstep', 'network', 'options', 'pdb', 'tests', 'window'],
    install_requires=['rpyc'],
    # package_data={'pdb': ['pdb_95.pir, pdb_95.bin']},
    include_package_data=True,
    scripts=['automodel.py']
)



import os
import wx
import wx.lib.agw.hyperlink as hl

from wintools.wintools import *
# from loader import *
from modellingfile.leitorprf import *
from modellingfile.seq import *
from modellingfile.fixpdb import *

from network.Clientold import Clientold
class SelectTemplate_Window(subwintools):#Subjanela de escolha de template
    def __init__(self, parent, id, arquivoBuild_ProfileAli):
        wx.Dialog.__init__(self, parent, id, 'Selecting a template protein',  size=(800,665))

        panel = wx.Panel(self, -1,  size=(800,665))
        panel.SetBackgroundColour("LightGray")
        self.statictext = {} #tupla para criacao de labels
        self.TextField = {} #tupla para criacao de campos de texto
        self.button = { } #tupla para a criacao de botoes
        self.profile = []
        self.profilepir = []
        self.createText(panel)
        self.createMuchButtons(panel)
        self.createTextFields(panel)


        texto = ""
        myseq = sequencia(arquivoBuild_ProfileAli, 1)
        for i in range(0, myseq.tamanho()):
                texto = texto + myseq.conteudodasequencia()[i]


        self.TextField["Target Sequence:"].SetValue(texto)
        fonte = wx.Font(9,  wx.MODERN, wx.NORMAL,  True)
        self.TextField["Target Sequence:"].SetFont(fonte)
        self.TextField["Selected Template:"].SetFont(fonte)
        self.Bind(wx.EVT_TEXT,self.OnTextinTemplate, self.TextField["Selected Template:"])
        self.button["Ok"].SetBackgroundColour("yellow")
        self.arquivoBuild_ProfileAli = arquivoBuild_ProfileAli
        self.parent = parent
        self.CreateAlinhamentoData(panel)
        self.RadiosDasEstruturas(panel)
        self.carregarPrimeiroRadio()
        self.result = None
        
        self.clientold = Clientold()

    def RadiosDasEstruturas(self, parent):
        arquivo = file(os.path.dirname(self.arquivoBuild_ProfileAli) + os.sep +"build_profile.prf", 'r')
        linha = arquivo.readline()
        while True:
            if not linha.startswith("#"):
                estrutura = estruturaprf(linha)
                if estrutura.Tipo() != "S":
                    self.profile.append(estrutura)
                linha = arquivo.readline()
                if linha == "":
                    break
            else:
                linha = arquivo.readline()

        for  i in range(0, len(self.profile)):
            for j in range(i, len(self.profile)):
                if self.profile[i].__str__() < self.profile[j].__str__():
                    temp = self.profile[i]
                    self.profile[i] = self.profile[j]
                    self.profile[j] = temp
        posX = 175
        posY = 298
        for estrutura in range(0, len(self.profile)):
            radio = wx.RadioButton(parent, -1, self.profile[estrutura].Nome(), pos = (posX, posY), name = self.profile[estrutura].Nome())
            myUrl = "http://pdb.org/pdb/explore/explore.do?structureId=" +  self.profile[estrutura].Nome()[0:4]
            self.Bind(wx.EVT_RADIOBUTTON,self.EventodosRadiosdeEstruturas, radio)
            myHl = hl.HyperLinkCtrl(parent, -1, "[?]", pos=(posX + 70, posY),
                                  URL=myUrl)
            myHl.SetToolTip(wx.ToolTip("Access on PDB.org"))
            posX = posX +100
            if estrutura == 4:
                posY = posY + 20
                posX = 175
            if estrutura >= 9:
                break
        for estrutura in range(1, len(self.profile)+2):
            self.profilepir.append(sequencia(self.arquivoBuild_ProfileAli,estrutura ))
        #self.TextField["Selected Template:"].SetValue(self.profilepir[1].nome())
    def carregarPrimeiroRadio(self):
                self.TextField["Start"].SetValue(self.profile[0].IniciodaEstrutura())
                self.TextField["End"].SetValue(self.profile[0].FimdaEstrutura())
                self.TextField["Quantity"].SetValue(self.profile[0].QuantidadedeResiduos())
                self.TextField["Identity"].SetValue(self.profile[0].Identidade())
                for estrutura in range(0, len(self.profilepir)):
                    #print self.profilepir[estrutura].nome().rsplit()[0]
                    if self.profilepir[estrutura].nome().rsplit()[0] == self.profile[0].Nome():
                        texto = ""
                        for i in range(0, self.profilepir[estrutura].tamanho()):
                           texto = texto + self.profilepir[estrutura].conteudodasequencia()[i]
                        self.TextField["Selected Template:"].SetValue(texto)
                        break
    def EventodosRadiosdeEstruturas(self, event):
        radioselecionado = event.GetEventObject()
        radioselecionado = radioselecionado.GetLabel()
        for inc in range(0, len(self.profile)):
            if radioselecionado == self.profile[inc].Nome():
                self.TextField["Start"].SetValue(self.profile[inc].IniciodaEstrutura())
                self.TextField["End"].SetValue(self.profile[inc].FimdaEstrutura())
                self.TextField["Quantity"].SetValue(self.profile[inc].QuantidadedeResiduos())
                self.TextField["Identity"].SetValue(self.profile[inc].Identidade())
                #print len(self.profilepir)
                for estrutura in range(0, len(self.profilepir)):
                    #print self.profilepir[estrutura].nome().rsplit()[0]
                    if self.profilepir[estrutura].nome().rsplit()[0] == radioselecionado:
                        texto = ""
                        for i in range(0, self.profilepir[estrutura].tamanho()):
                           texto = texto + self.profilepir[estrutura].conteudodasequencia()[i]
                        self.TextField["Selected Template:"].SetValue(texto)
                break
            else:
                pass
    def textData(self): #labels
        return(("Select below a protein that is used as a template:", (20, 20)),)

    def textFieldData(self): #campo de dados
        return(("Target Sequence:", (30, 40)),
                        ("Selected Template:", (30,350)))
    def alinhamentoData(self):
      return(["Start","End", "Quantity", "Identity"])

    def CreateAlinhamentoData(self,panel):
      posicaoY = 395
      posicaoX = 50
      for cadaParameto in self.alinhamentoData():
        static = wx.StaticText(panel, wx.NewId(), cadaParameto, pos=(posicaoX,posicaoY))
        self.TextField[cadaParameto] = wx.TextCtrl(panel, wx.NewId(), "", size=(40,30), pos=(posicaoX,posicaoY+18))
        posicaoY = posicaoY + 55
      wx.StaticBox(panel,  -1, "Alignment", (35, 375), (95, posicaoY-375))
      wx.StaticText(panel, wx.NewId(), "%", pos=(93, 585))
    def buttonData(self): #botoes
        return(("Ok",self.Alinhar, (520,610)),
                    ("Cancel",self.OnCloseWindow, (420,610)),
                    ("PIR Alignment",self.OnButtonOpenAli,(290,610)),
                    ("PAP Alignment ",self.OnButtonOpenPAP,(160,610)))

    def Alinhar(self,event):
        texto1 = self.TextField["Target Sequence:"].GetValue()
        texto2 = self.TextField["Selected Template:"].GetValue()
        self.result = [texto1,texto2]
        self.Destroy()
#    def __del__(self):
#        return self.result
##        super.__del__()
#    def __str__(self):
#        return self.result
    def out(self):
        return self.result

    def OnButtonOpenAli(self, event): #Botoes de abertura de arquivos de textos
        try:
          self.clientold.open_txt_file(self.arquivoBuild_ProfileAli)
        except Exception, e:
          self.choose_text_editor(self.arquivoBuild_ProfileAli)

    def OnButtonOpenPAP(self, event): #Botoes de abertura de arquivos de textos
        arquivoPAP = os.path.dirname(self.arquivoBuild_ProfileAli) + os.sep +'build_profilePAP.ali'
        try:
          self.clientold.open_txt_file(arquivoPAP)
        except Exception, e:
          self.choose_text_editor(arquivoPAP)

    def OnTextinTemplate(self, event): #Verifica sem tem algum texto no campo Sequencia
        if(self.TextField["Selected Template:"].GetValue() != ""):
         self.button["Ok"].SetBackgroundColour("green")
        else:
         self.button["Ok"].SetBackgroundColour("yellow")


# if __name__ == '__main__':
    # app = wx.PySimpleApp()
    # arquivo = 'c:' + os.sep + 'build_profilePIR.ali'
    # frame = Automodel2(None,-1, arquivo)

    # frame.ShowModal()
   # app.MainLoop()





#Boa:MiniFrame:MiniFrame1

import wx
import wx.richtext
#from loader import *
import os
import tempfile

def create(parent):
    return MiniFrame1(parent)

[wxID_MINIFRAME1, wxID_MINIFRAME1BUTTON1, wxID_MINIFRAME1BUTTON2,
 wxID_MINIFRAME1BUTTON3, wxID_MINIFRAME1RICHTEXTCTRL1,
 wxID_MINIFRAME1STATICTEXT1,
] = [wx.NewId() for _init_ctrls in range(6)]

class MiniFrame1(wx.MiniFrame):
    def _init_ctrls(self, prnt):
        # generated method, don't edit
        wx.MiniFrame.__init__(self, id=wxID_MINIFRAME1, name='', parent=prnt,
              pos=wx.Point(261, 262), size=wx.Size(776, 480),
              style=wx.DEFAULT_FRAME_STYLE, title='Load Target Sequence')
        self.SetClientSize(wx.Size(776, 480))

        self.staticText1 = wx.StaticText(id=wxID_MINIFRAME1STATICTEXT1,
              label=u'Enter in the below camp the protein sequence (target sequence) that you wants to model',
              name='staticText1', parent=self, pos=wx.Point(40, 40),
              size=wx.Size(601, 15), style=0)

        self.button1 = wx.Button(id=wxID_MINIFRAME1BUTTON1, label=u'Save',
              name='button1', parent=self, pos=wx.Point(480, 400),
              size=wx.Size(85, 28), style=0)
        self.button1.Bind(wx.EVT_BUTTON, self.OnSalvarButton,
              id=wxID_MINIFRAME1BUTTON1)

        self.button2 = wx.Button(id=wxID_MINIFRAME1BUTTON2, label=u'Cancel',
              name='button2', parent=self, pos=wx.Point(336, 400),
              size=wx.Size(85, 28), style=0)
        self.button2.Bind(wx.EVT_BUTTON, self.OnCancelarButton,
              id=wxID_MINIFRAME1BUTTON2)

        self.button3 = wx.Button(id=wxID_MINIFRAME1BUTTON3, label=u'Clear',
              name='button3', parent=self, pos=wx.Point(192, 400),
              size=wx.Size(85, 28), style=0)
        self.button3.Bind(wx.EVT_BUTTON, self.OnLimparButton,
              id=wxID_MINIFRAME1BUTTON3)

        self.richTextCtrl1 = wx.richtext.RichTextCtrl(id=wxID_MINIFRAME1RICHTEXTCTRL1,
              parent=self, pos=wx.Point(32, 64), size=wx.Size(712, 224),
              style=wx.richtext.RE_MULTILINE, value=u'')
        self.richTextCtrl1.SetLabel(u'')

    def __init__(self, parent):
        self._init_ctrls(parent)
        self.parent = parent

    def OnLimparButton(self, event):
        self.richTextCtrl1.SetValue("")

    def OnSalvarButton(self, event):
		texto = self.richTextCtrl1.GetValue()
		pir = self.makefasta(texto)
		arquivo = self.buildfile(pir)
# self.parent.send_fasta_file(arquivo)
		self.fasta_filename = arquivo
		self.parent.OnButton2ButtonDone(arquivo)
		self.Destroy()

    def OnCancelarButton(self, event):
        self.Destroy()

    def makefasta(self,texto): #retorna, uma sequencia fasta ou somente cadeia, em formato PIR
		if texto.startswith('>'):
		    texto = texto.partition('\n')[2]
		retorno ='>seq.ali\n' + texto
		return(retorno)

    def buildfile(self,conteudo):
		arquivo = tempfile.mktemp()
		arq = file(arquivo, 'w')
		arq.write(conteudo)
		arq.close()
#		print arquivo
		return(arquivo)
#        if self.richTextCtrl1.GetValue() != "":
#            if getModellerPid() == 0:
#                #event.Skip()
#                texto =  self.richTextCtrl1.GetValue()
#                pir = makepir(texto)
#                self.parent.file = buildfile(pir)
#                self.parent.pasta = os.path.dirname(self.parent.file)
#                self.parent.PrepararDepoisdeLer(self.parent.file)
#                self.Destroy()
#            elif self.parent.FinalizarModeller():
#                #event.Skip()
#                texto =  self.richTextCtrl1.GetValue()
#                pir = makepir(texto)
#                self.parent.file = buildfile(pir)
#                self.parent.pasta = os.path.dirname(self.parent.file)
#                self.parent.PrepararDepoisdeLer(self.parent.file)
#                self.Destroy()
#
#        else:
#            dlg = wx.MessageBox("Nao foi digitado nada", caption="Alpha", style=wx.OK)

#parent = wx.App()
#main = MiniFrame1(parent,"/tmp")
#main.Show()




class file(file):
	def is_fasta(self):
		readlines = self.readline()
		first_line = readlines[0].decode()
		last_line = readlines[-1].decode()
		print last_line
		return first_line.startswith(">") and not last_line.endswith("*\n")

	def load_in_memory(self):
		self.seek(0,2)
		size = self.tell()
		self.seek(0)
		buffer = self.read(size)
		return buffer


# import rpyc
from MiniServer.adapter import ServerAdapter
# from server_test import server
import shutil
from modellingfile.file import file
import os

class Client(object):
	"""docstring for Client"""
	def __init__(self):
		self.__version__ = "0.40"
		self.myserial = ""

	def connect_with_server(self):
		# self.__connection__ = rpyc.connect(self.__server_adress__, self.__server_port__)
		self.__server__ = ServerAdapter()

	def check_serial(self,serial):
		self.connect_with_server()
		self.myserial = serial
		return self.__server__.check_serial(serial)

	def send_file(self,file_name):
		sending_file = file(file_name, "r")
		buffer_file = sending_file.load_in_memory()
		sending_file.close()
		self.__server__.receive_file(os.path.basename(file_name), buffer_file)

	def find_templates(self):
		self.__server__.find_templates(self.myserial)

	def receive_file(self, name_of_file):
		buffer_file = self.__server__.send_file(name_of_file)
		my_file = file(name_of_file, "w")
		my_file.write(buffer_file)
		my_file.close()

	def get_pdb_from_server(self, pdb_name):
		buffer_file = self.__server__.send_template(pdb_name)
		return buffer_file

	def align(self,pir_sequence_file,template):
		self.__server__.align(pir_sequence_file,template)
		
	def model(self,ali_ali, template):
		return self.__server__.model(ali_ali, template)

	def evaluate(self,template,model_file,ali_ali_file):
		return self.__server__.evaluate(template,model_file,ali_ali_file)

	def evaluatePROCHECK(self, model_file):
		return self.__server__.evaluatePROCHECK(model_file)

	def loopmodel(self, model_file, start_residue, end_residue):
		return self.__server__.loopmodel(model_file, start_residue, end_residue)
	def evaluatelooprefinament(self, template,model_file,loopmodel, ali_ali_file):
		return self.__server__.evaluatelooprefinament(template,model_file,loopmodel, ali_ali_file)

	def disconnect(self):
		# self.__connection__.close()
		pass




#Boa:Dialog:AboutAutoModel

import wx

def create(parent):
    return AboutAutoModel(parent)

[wxID_ABOUTAUTOMODEL, wxID_ABOUTAUTOMODELAUTOMODELNAME, 
 wxID_ABOUTAUTOMODELBUTTONOK, wxID_ABOUTAUTOMODELSTATICTEXT1, 
 wxID_ABOUTAUTOMODELSTATICTEXT2, 
] = [wx.NewId() for _init_ctrls in range(5)]

class AboutAutoModel(wx.Dialog):
    def _init_ctrls(self, prnt):
        # generated method, don't edit
        wx.Dialog.__init__(self, id=wxID_ABOUTAUTOMODEL, name=u'AboutAutoModel',
              parent=prnt, pos=wx.Point(428, 305), size=wx.Size(395, 222),
              style=wx.DEFAULT_DIALOG_STYLE, title=u'About AutoModel')
        self.SetClientSize(wx.Size(395, 222))

        self.buttonOk = wx.Button(id=wxID_ABOUTAUTOMODELBUTTONOK, label=u'OK',
              name=u'buttonOk', parent=self, pos=wx.Point(160, 176),
              size=wx.Size(85, 27), style=0)
        self.buttonOk.Bind(wx.EVT_BUTTON, self.OnButtonOkButton,
              id=wxID_ABOUTAUTOMODELBUTTONOK)

        self.automodelName = wx.StaticText(id=wxID_ABOUTAUTOMODELAUTOMODELNAME,
              label=u'AutoModel version 0.5', name=u'automodelName',
              parent=self, pos=wx.Point(124, 22), size=wx.Size(147, 17),
              style=0)

        self.staticText1 = wx.StaticText(id=wxID_ABOUTAUTOMODELSTATICTEXT1,
              label=u'Copyright 2009-2014', name='staticText1', parent=self,
              pos=wx.Point(128, 136), size=wx.Size(137, 17), style=0)

        self.staticText2 = wx.StaticText(id=wxID_ABOUTAUTOMODELSTATICTEXT2,
              label=u'E-mail: automodel@gmail.com', name='staticText2',
              parent=self, pos=wx.Point(88, 80), size=wx.Size(203, 17),
              style=0)

    def __init__(self, parent):
        self._init_ctrls(parent)

    def OnButtonOkButton(self, event):
        self.Destroy()
